@@ -306,10 +306,12 @@ Seq    |          MyClass.myfunction : END
   * \section tjutils_intro Introduction
   * Well known data types, such as integers, floating point numbers, complex numbers, strings,
   * vectors (1-dimensional) and arrays (multi-dimensional) are used in ODIN.
-  * For all types discussed in this section, there exists a corresponding JCAMP-DX type (\ref jcampdx).
-  * This JCAMPD-DX type is prefixed by 'JDX' and then the data type, e.g. 'STD_string' has a JCAMP-DX
-  * counterpart 'JDXstring' with the same functionality.
-  * In addition, JCAMP-DX parameters can be assigned a label, grouped together with other JCAMP-DX parameters, etc.
+  * For all these basic types discussed in this section,
+  * there exists a corresponding labeled data record (LDR) type (\ref ldr).
+  * This LDR type is prefixed by 'LDR' followed the data type, e.g. 'float' has a LDR
+  * counterpart 'LDRfloat' with the same basic functionality.
+  * In addition, LDR parameters can be assigned a label, grouped together with other LDR parameters,
+  * written to and read from file etc.
   *
   * \section vectors Vectors
   * Vectors are implemented by the tjvector template class which is
@@ -329,13 +331,13 @@ Seq    |          MyClass.myfunction : END
   * It is derived from the tjvector class to store the data. In addition,
   * the information about the dimensionality and extent in each dimension
   * is stored separately in the class by an ndim object.
-  * Some predefined array classes and their corresponding JCAMP-DX type are
+  * Some predefined array classes and their corresponding LDR type are
   * created by using the tjarray template class:
-  * - farray / JDXfloatArr:   array of float numbers
-  * - darray / JDXdoubleArr:  array of double precision float numbers
-  * - iarray / JDXintArr:     array of int numbers
-  * - sarray / JDXstringArr:  array of strings (STD_string objects)
-  * - carray / JDXcomplexArr: array of complex numbers (STD_complex objects)
+  * - farray / LDRfloatArr:   array of float numbers
+  * - darray / LDRdoubleArr:  array of double precision float numbers
+  * - iarray / LDRintArr:     array of int numbers
+  * - sarray / LDRstringArr:  array of strings (STD_string objects)
+  * - carray / LDRcomplexArr: array of complex numbers (STD_complex objects)
   *
   * Some examples on how to use these arrays:
   *\code{.cpp}
@@ -364,9 +366,9 @@ fa1.redim(1,2,3);     // resizes fa1 to a 3-dimensional 1x2x3 array
 ///////////////////////////////////////////////////////////////////////////////////////
 
 /**
-  * @defgroup jcampdx JCAMP-DX implementation (odinpara library)
+  * @defgroup ldr Labeled Data Record (LDR) implementation (odinpara library)
   *
-  * This page describes the design guidelines of the module \ref jcampdx
+  * This page describes the design guidelines of the module \ref ldr
   *
   * The following framework can be used to deal with single parameters of different
   * type (int,float,string,...) and multidimensional arrays that are build from these
@@ -379,11 +381,11 @@ fa1.redim(1,2,3);     // resizes fa1 to a 3-dimensional 1x2x3 array
   * A very simple examples on how to use this module:
   *\code{.cpp}
 
-JDXint mynumber(23,"mynumber");  // Create an integer parameter with initial value 23
+LDRint mynumber(23,"mynumber");  // Create an integer parameter with initial value 23
 
-mynumber+=42;                    // JDXint can be used just as a native int for arithmetics
+mynumber+=42;                    // LDRint can be used just as a native int for arithmetics
 
-JcampDxBlock block;              // A block (list) of parameters
+LDRblock block;              // A block (list) of parameters
 
 block.append(mynumber);          // Append the parameter to the block
 
@@ -628,6 +630,17 @@ block.load("block.jdx");         // Load block and its parameters from file 'blo
   * gensample: \ref gensample
   *
   * swab: \ref swab
+  *
+  * For command-line-based simulation of Odin sequences (e.g. for sequence 'mysequence'):
+  * - Create a Makefile using 'genmakefile' on the command line:
+  *   \verbatim
+       genmakefile mysequence > Makefile
+      \endverbatim
+  * - Copy mysequence.cpp to the same directory, then use 'make' to build the executable 'mysequence'
+  * - Calling the executable without arguments shows the options. For instance, the simulation can be started with:
+  *   \verbatim
+       mysequence simulate -magsi -s <The virtual sample file> -p <The file with the measurement protocol> -scandir <output-dir>
+      \endverbatim
   */
 
 ///////////////////////////////////////////////////////////////////////////////////////
