@@ -71,8 +71,8 @@ void usage(const Protocol& prot) {
   STD_cout << "       micalc [-if1 <input-file1> | -in1 <input-number1>] -op <operation(+,-,*,/,min,max,lcorr,kcorr)> [-if2 <input-file2> | -in2 <input-number1>] -of <output-file>" << STD_endl;
   STD_cout << "  Accumulation/reduction of one data set:" << STD_endl;
   STD_cout << "       micalc -if <input-file> -op <operation(+,*,mean,median,stdev,min,max)>" << STD_endl;
-  STD_cout << "  Transformation (magnitude, logarithm, negation, inversion, or acos) of one data set:" << STD_endl;
-  STD_cout << "       micalc -if <input-file> -op <operation(abs,log,-,/,acos)> -of <output-file>" << STD_endl;
+  STD_cout << "  Transformation (magnitude, logarithm, ...) of one data set:" << STD_endl;
+  STD_cout << "       micalc -if <input-file> -op <operation(abs,log,exp,-,/,acos)> -of <output-file>" << STD_endl;
   STD_cout << "  Statistics of one data set:" << STD_endl;
   STD_cout << "       micalc -if <input-file> [-mean <time-mean-file>] [-stdev <time-stdev-file>] [-fluct <relative-time-stdev-file>] [-tcourse <average time course of all voxels>]"
                       "[-hist <histogram> -histslots <numofslots> [-histmin <minval>] [-histmax <maxval>] [-rightstairs] [-histfract] [-loghist] [-histslotmap <file>]]" << STD_endl;
@@ -99,8 +99,6 @@ void usage(const Protocol& prot) {
 bool read_infile(const STD_string& filename, Data<float,4>& data, const FileReadOpts& ropts, Protocol& prot, const FilterChain& filterchain) {
   Log<OdinData> odinlog("micalc","read_infile");
 
-  Range all=Range::all();
-
   Data<float,4> datain;
 
   if(datain.autoread(filename,ropts,&prot)<0) return false;
@@ -272,7 +270,7 @@ int main(int argc, char* argv[]) {
     if( inmaskdata.extent(0) && same_shape(data1, inmaskdata, TinyVector<int,4>(0,1,1,1) ) ) {
       maskdata.resize(data1.shape());
       maskdata=0.0;
-      for(int i=0; i<data1.numElements(); i++) {
+      for(unsigned int i=0; i<data1.numElements(); i++) {
         TinyVector<int,4> index=data1.create_index(i);
         TinyVector<int,4> maskindex=index; maskindex(0)=0;
         if(inmaskdata(maskindex)!=0.0) maskdata(index)=1.0;
@@ -300,7 +298,7 @@ int main(int argc, char* argv[]) {
       Array<float,1> vec1(npts);
       Array<float,1> vec2(npts);
       int vecindex=0;
-      for(int i=0; i<data1.numElements(); i++) {
+      for(unsigned int i=0; i<data1.numElements(); i++) {
         TinyVector<int,4> index=data1.create_index(i);
         bool include=true;
         if( maskptr && maskdata(index)==0.0 ) include=false;
@@ -325,7 +323,7 @@ int main(int argc, char* argv[]) {
       if(operation=="min" || operation=="max") {
         Data<float,4> minval(outshape);
         Data<float,4> maxval(outshape);
-        for(int i=0; i<data1.numElements(); i++) {
+        for(unsigned int i=0; i<data1.numElements(); i++) {
           TinyVector<int,4> index=data1.create_index(i);
           minval(index)=STD_min(data1(index), data2(index));
           maxval(index)=STD_max(data1(index), data2(index));
@@ -372,6 +370,7 @@ int main(int argc, char* argv[]) {
     bool validop=false;
     if(operation=="abs")  {validop=true; result=fabs(data1);}
     if(operation=="log")  {validop=true; result=where(Array<float,4>(data1)>0.0, Array<float,4>(log(data1)), float(0.0));}
+    if(operation=="exp")  {validop=true; result=exp(data1);}
     if(operation=="-")    {validop=true; result=-data1;}
     if(operation=="/")    {validop=true; result=where(Array<float,4>(data1)!=0.0, Array<float,4>(1.0/data1), float(0.0));}
     if(operation=="acos") {validop=true; result=where(Array<float,4>(data1)>=-1.0 && Array<float,4>(data1)<=1.0, Array<float,4>(acos(data1)), float(0.0));}
@@ -390,7 +389,7 @@ int main(int argc, char* argv[]) {
       int nvals=data1.numElements();
       if(maskptr) {
         nvals=0;
-        for(int i=0; i<maskdata.numElements(); i++) {
+        for(unsigned int i=0; i<maskdata.numElements(); i++) {
           TinyVector<int,4> index=maskdata.create_index(i);
           if( maskdata(index)>0.0 ) {
             nvals++;
@@ -441,7 +440,7 @@ int main(int argc, char* argv[]) {
 
         for(int i=0; i<nslots; i++) xvals(i)=pow(float(10.0),float(minpow+(float(i)+stairoffset)*step));
 
-        for(int i=0; i<data1.numElements(); i++) {
+        for(unsigned int i=0; i<data1.numElements(); i++) {
           TinyVector<int,4> index=data1.create_index(i);
           if( !(maskptr && maskdata(index)==0.0) ) {
             float pow=log10(data1(index));
@@ -463,7 +462,7 @@ int main(int argc, char* argv[]) {
 
         for(int i=0; i<nslots; i++) xvals(i)=minval+(float(i)+stairoffset)*step;
 
-        for(int i=0; i<data1.numElements(); i++) {
+        for(unsigned int i=0; i<data1.numElements(); i++) {
           TinyVector<int,4> index=data1.create_index(i);
           if( !(maskptr && maskdata(index)==0.0) ) {
             float val=data1(index);
@@ -494,7 +493,7 @@ int main(int argc, char* argv[]) {
       Data<float,4> stdevresult(outshape); stdevresult=0.0;
       Data<float,1> tcourseresult(data1.extent(0)); tcourseresult=0.0;
       int tcoursepts=0;
-      for(int i=0; i<meanresult.numElements(); i++) {
+      for(unsigned int i=0; i<meanresult.numElements(); i++) {
         TinyVector<int,4> index=meanresult.create_index(i);
         if(!index(0)) { // only once for all repetitions
           if( !(maskptr && maskdata(index)==0.0) ) {
