@@ -165,22 +165,22 @@ int main(int argc, char* argv[]) {
     }
     int nrows=ndsets;
     if(npars>1) nrows++;
-    sarray table(ncols,nrows);
+    sarray table(nrows,ncols);
     if(npars>1) {
       for(int ipar=0; ipar<npars; ipar++) {
-        table(ipar,0)=pars[ipar];
+        table(0,ipar)=pars[ipar];
       }
-      table(npars,0)="Dataset";
+      table(0,npars)="Dataset";
       irow++;
     }
     for(FileIO::ProtocolDataMap::const_iterator pdit=pdmap_in.begin(); pdit!=pdmap_in.end(); ++pdit) {
       for(int ipar=0; ipar<npars; ipar++) {
-        table(ipar,irow)=rmblock(pdit->first.printval(pars[ipar]), "\n", ""); // truncate after first newline
+        table(irow,ipar)=rmblock(pdit->first.printval(pars[ipar]), "\n", ""); // truncate after first newline
       }
       if(ndsets>1) {
         STD_ostringstream oss;
         oss << pdit->second.shape();
-        table(npars,irow)=oss.str();
+        table(irow,npars)=oss.str();
       }
       irow++;
     }
