@@ -18,16 +18,17 @@ void alloc_IndexTest();
 void alloc_ProcessTest();
 void alloc_ThreadTest();
 void alloc_DownhillSimplexTest();
-void alloc_JDXstringArrTest();
-void alloc_JDXintArrTest();
-void alloc_JDXcomplexArrTest();
+void alloc_LDRstringArrTest();
+void alloc_LDRintArrTest();
+void alloc_LDRcomplexArrTest();
 void alloc_GeometryTest();
-void alloc_JDXintTest();
-void alloc_JDXstringTest();
-void alloc_JDXcomplexTest();
-void alloc_JDXboolTest();
-void alloc_JDXenumTest();
-void alloc_JDXfileNameTest();
+void alloc_LDRintTest();
+void alloc_LDRstringTest();
+void alloc_LDRcomplexTest();
+void alloc_LDRboolTest();
+void alloc_LDRenumTest();
+void alloc_LDRfileNameTest();
+void alloc_LDRserTest();
 void alloc_CoilSensitivityTest();
 void alloc_ProtocolTest();
 void alloc_DataUtilsTest();
@@ -66,15 +67,16 @@ int main(int argc, char* argv[]) {
   alloc_IndexTest();
   alloc_ProcessTest();
   alloc_ThreadTest();
-  alloc_JDXintTest();
-  alloc_JDXstringTest();
-  alloc_JDXcomplexTest();
-  alloc_JDXboolTest();
-  alloc_JDXenumTest();
-  alloc_JDXfileNameTest();
-  alloc_JDXstringArrTest();
-  alloc_JDXintArrTest();
-  alloc_JDXcomplexArrTest();
+  alloc_LDRserTest();
+  alloc_LDRintTest();
+  alloc_LDRstringTest();
+  alloc_LDRcomplexTest();
+  alloc_LDRboolTest();
+  alloc_LDRenumTest();
+  alloc_LDRfileNameTest();
+  alloc_LDRstringArrTest();
+  alloc_LDRintArrTest();
+  alloc_LDRcomplexArrTest();
   alloc_GeometryTest();
   alloc_CoilSensitivityTest();
   alloc_ProtocolTest();
