@@ -103,14 +103,14 @@ void GeoEditView::geometryChanged() {
 
   if(old_mode!=mode) {
     if(old_mode!=n_geometry_modes) blockwidget[old_mode]->hide();
-    if(blockwidget[mode]==0) blockwidget[mode]=new JDXwidget(geometry_cache,3,this);
+    if(blockwidget[mode]==0) blockwidget[mode]=new LDRwidget(geometry_cache,3,this);
     blockwidget[mode]->show();
     grid->add_widget( blockwidget[mode], 1,0, GuiGridLayout::Center, 6,5);
     connect(blockwidget[mode],SIGNAL(valueChanged()),this,SLOT(geometryChanged()));
   }
   blockwidget[mode]->updateWidget();
   old_mode=mode;
-  ODINLOG(odinlog,normalDebug) << "JDXwidget done" << STD_endl;
+  ODINLOG(odinlog,normalDebug) << "LDRwidget done" << STD_endl;
 
   for(STD_list<GeoEditLabel*>::iterator labelit=labels.begin(); labelit!=labels.end(); ++labelit) {
     (*labelit)->drawImagingArea(geometry_cache,projection->is_on(),crosssect->is_on());
