@@ -2,7 +2,7 @@
                           geoeditview.h  -  description
                              -------------------
     begin                : Mon Apr 15 18:40:55 CEST 2002
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -19,7 +19,7 @@
 #define GEOEDITVIEW_H
 
 
-#include <odinqt/jdxwidget.h>
+#include <odinqt/ldrwidget.h>
 
 #include <odinpara/geometry.h>
 
@@ -59,7 +59,7 @@ class GeoEditView : public QWidget {
     Geometry& geometry_cache;
     ImageSet& pilot_cache;
 
-    JDXwidget* blockwidget[n_geometry_modes];
+    LDRwidget* blockwidget[n_geometry_modes];
 
     GuiGridLayout* grid;
 
