@@ -149,7 +149,7 @@ bool MiViewFmri::init(const FileReadOpts& ropts, const Protocol& prot, const Fil
     float tr=data->protcopy.seqpars.get_RepetitionTime();
     ODINLOG(odinlog,infoLog) << "Convolving with HRF and TR=" << tr << STD_endl;
     fvector designcopy(design);
-    design=JDXfloat(0.0);
+    design=LDRfloat(0.0);
     for(int i=0; i<nrep; i++) {
       for(int j=i; j<nrep; j++) {
         design(j)+=designcopy[i]*glover_hrf((j-i)*0.001*tr);
