@@ -2,7 +2,7 @@
                           miview_fmri.h  -  description
                              -------------------
     begin                : Mon Jan 2 19:02:26 CEST 2006
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -18,10 +18,10 @@
 #ifndef MIVIEW_FMRI_H
 #define MIVIEW_FMRI_H
 
-#include <odinpara/jdxnumbers.h>
-#include <odinpara/jdxtypes.h>
-#include <odinpara/jdxblock.h>
-#include <odinpara/jdxarrays.h>
+#include <odinpara/ldrnumbers.h>
+#include <odinpara/ldrtypes.h>
+#include <odinpara/ldrblock.h>
+#include <odinpara/ldrarrays.h>
 
 // forward declarations
 class FileReadOpts;
@@ -31,7 +31,7 @@ struct FmriData;
 
 ////////////////////////////////////////////////////////////
 
-class MiViewFmri : public JcampDxBlock {
+class MiViewFmri : public LDRblock {
 
  public:
   MiViewFmri();
@@ -47,25 +47,25 @@ class MiViewFmri : public JcampDxBlock {
   void update();
 
  private:
-  JDXstring designfile;
-  JDXstring fmrifile;
-  JDXstring maskfile;
-  JDXbool bonferr;
-  JDXbool hrf;
-  JDXfloat corr;
-  JDXfloat zscore;
-  JDXint designavg;
-  JDXint neighb;
-  JDXstring sigchange;
-  JDXfloat zsum;
-  JDXint zcount;
-  JDXstring zaverage;
-  JDXfloatArr design;
-  JDXfloatArr tcourse;
-  JDXfloatArr sigcourse;
-  JDXstring dumptcourse;
-  JDXstring dumpzmap;
-  JDXstring dumpsmap;
+  LDRstring designfile;
+  LDRstring fmrifile;
+  LDRstring maskfile;
+  LDRbool bonferr;
+  LDRbool hrf;
+  LDRfloat corr;
+  LDRfloat zscore;
+  LDRint designavg;
+  LDRint neighb;
+  LDRstring sigchange;
+  LDRfloat zsum;
+  LDRint zcount;
+  LDRstring zaverage;
+  LDRfloatArr design;
+  LDRfloatArr tcourse;
+  LDRfloatArr sigcourse;
+  LDRstring dumptcourse;
+  LDRstring dumpzmap;
+  LDRstring dumpsmap;
 
   FmriData* data;
   mutable farray overlay_map;
