@@ -1,6 +1,6 @@
 #include "miviewview.h"
 
-#include <odinpara/jdxtypes.h>
+#include <odinpara/ldrtypes.h>
 #include <odinpara/protocol.h>
 
 #include <odindata/fileio.h>
@@ -8,7 +8,7 @@
 #include <odindata/utils.h>
 #include <odindata/filter.h>
 
-#include <odinqt/jdxblockwidget.h> // for showProtocol
+#include <odinqt/ldrblockwidget.h> // for showProtocol
 
 #include <tjutils/tjlog_code.h>
 
@@ -57,8 +57,8 @@ MiViewOpts::MiViewOpts() {
   recfile.set_cmdline_option("rec").set_description("Record clicked coordinates and values into this file");
   append_member(recfile,"recfile");
 
-  blowup=1;
-  blowup.set_cmdline_option("blowup").set_description("Enlarge display size by this factor");
+  blowup=0;
+  blowup.set_cmdline_option("blowup").set_description("Enlarge display size by this factor (0=automatic)");
   append_member(blowup,"blowup");
 
   low.set_cmdline_option("low").set_description("Lower windowing boundary: This value will appear black in display");
@@ -67,7 +67,7 @@ MiViewOpts::MiViewOpts() {
   upp.set_cmdline_option("upp").set_description("Upper windowing boundary: This value will appear white in display");
   append_member(upp,"upp");
 
-  dump.set_cmdline_option("dump").set_description("Dump all images as bitmap(bmp) files and exit, use the given filename prefix");
+  dump.set_cmdline_option("dump").set_description("Dump all images as graphic files and exit, use the given filename postfix to specify the format");
   append_member(dump,"dump");
 
   mapfile.set_cmdline_option("map").set_description("Load overlay map (colored voxels superimposed on image) from this file");
@@ -171,7 +171,7 @@ MiViewView::MiViewView(QWidget *parent) : QWidget(parent) {
 
   FilterChain filterchain(GuiApplication::argc(),GuiApplication::argv());
 
-  JDXfileName fname;
+  LDRfileName fname;
   if(getLastArgument(GuiApplication::argc(),GuiApplication::argv(),optval,ODIN_MAXCHAR)) {
     fname=optval;
   } else {
@@ -208,8 +208,8 @@ MiViewView::MiViewView(QWidget *parent) : QWidget(parent) {
   if(uppbound<=lowbound) has_bounds=false; // check input
   ODINLOG(odinlog,normalDebug) << "lowbound/uppbound/has_bounds=" << lowbound << "/" << uppbound << "/" << has_bounds << STD_endl;
 
-
-  guiprops_cache.pixmap.minsize=mopts.blowup*256;
+  if(mopts.blowup>0) guiprops_cache.pixmap.minsize=mopts.blowup*STD_min(get_nx(), get_ny());
+  else               guiprops_cache.pixmap.minsize=256;
   guiprops_cache.fixedsize=false;
   guiprops_cache.pixmap.autoscale=false;
   guiprops_cache.pixmap.color=mopts.color;
@@ -217,6 +217,8 @@ MiViewView::MiViewView(QWidget *parent) : QWidget(parent) {
   guiprops_cache.pixmap.overlay_minval=mopts.maplow;
   guiprops_cache.pixmap.overlay_maxval=mopts.mapupp;
 
+  ODINLOG(odinlog,normalDebug) << "guiprops.pixmap.minsize=" << guiprops_cache.pixmap.minsize << STD_endl;
+
   has_olm=false;
   if(mopts.mapfile!="") {
     Data<float,4> mapdata;
@@ -236,7 +238,7 @@ MiViewView::MiViewView(QWidget *parent) : QWidget(parent) {
     guiprops_cache.pixmap.overlay_firescale=true;
     fmri.update();
     fmri.set_label("fMRI");
-    fmriwidget=new JDXwidget(fmri, 1, this);
+    fmriwidget=new LDRwidget(fmri, 1, this);
     connect(fmriwidget,SIGNAL(valueChanged()),this,SLOT(update()));
   }
 
@@ -247,14 +249,24 @@ MiViewView::MiViewView(QWidget *parent) : QWidget(parent) {
 
 
   displaydata.set_label("Data Plot");
-  displaywidget=new JDXwidget(displaydata, 1, this);
+  displaywidget=new LDRwidget(displaydata, 1, this);
 
   export_legend(mopts.legendexport); // Do this after displaywidget is initialized, bur before dump. String will be checked in export_map_legend()
   export_map_legend(mopts.maplegendexport); // Do this after displaywidget is initialized, bur before dump. String will be checked in export_map_legend()
 
   if(mopts.dump!="") {
-    ODINLOG(odinlog,infoLog) << "Dumping images with prefix " << mopts.dump << STD_endl;
-    displaywidget->write_pixmap(mopts.dump.c_str(), "bmp", true);
+
+    STD_string dumpfname(mopts.dump);
+
+    STD_string format=check_and_get_format(mopts.dump, get_possible_image_fileformats(), false);
+    if(format=="") {
+      format="bmp"; // default
+      dumpfname+="."+format;
+      ODINLOG(odinlog,warningLog) << "Unknown file format, using format" << format << STD_endl;
+    }
+
+    ODINLOG(odinlog,infoLog) << "Dumping images with filename " << dumpfname << " and format " << format << STD_endl;
+    displaywidget->write_pixmap(dumpfname.c_str(), format.c_str(), true);
     exit(0);
   }
 
@@ -280,7 +292,7 @@ MiViewView::MiViewView(QWidget *parent) : QWidget(parent) {
   ODINLOG(odinlog,normalDebug) << "n_settings=" << n_settings << STD_endl;
   if(n_settings) {
     settings.set_label("Display Settings");
-    settingswidget=new JDXwidget(settings, 1, this);
+    settingswidget=new LDRwidget(settings, 1, this);
     connect(settingswidget,SIGNAL(valueChanged()),this,SLOT(update()));
   }
 
@@ -291,7 +303,7 @@ MiViewView::MiViewView(QWidget *parent) : QWidget(parent) {
     timecourse.set_gui_props(tcgp);
     timecourse.set_label("Timecourse");
     timecourse.redim(get_nrep());
-    tcoursewidget=new JDXwidget(timecourse, 1, this);
+    tcoursewidget=new LDRwidget(timecourse, 1, this);
   }
 
   int ncols=1;
@@ -313,6 +325,14 @@ MiViewView::MiViewView(QWidget *parent) : QWidget(parent) {
 
 }
 
+void MiViewView::writeData() {
+  data_fname_cache=get_save_filename("Data File", data_fname_cache.c_str(), "", this);
+  if(data_fname_cache=="") return;
+  STD_string format=check_and_get_format(data_fname_cache,FileIO::autoformats());
+  if(format!="") {
+    file->data.autowrite(data_fname_cache, FileWriteOpts(), &(file->prot));
+  }
+}
 
 void MiViewView::writeImage() {
   image_fname_cache=get_save_filename("Image File for Screen Dump", image_fname_cache.c_str(), "", this);
@@ -397,14 +417,14 @@ void MiViewView::writeMapLegend() {
 
 void MiViewView::selectVoxel() {
 
-  JcampDxBlock block;
+  LDRblock block;
   for(int idir=(n_directions-1); idir>=0; idir--) { // display reversed in dialog
     pos_cache[idir].set_label(directionLabel[idir]);
     pos_cache[idir].set_description("Voxel index in "+STD_string(directionLabel[idir])+" direction").set_unit("pixel");
     block.append(pos_cache[idir]);
   }
 
-  new JDXwidgetDialog(block,n_directions,this,true);
+  new LDRwidgetDialog(block,n_directions,this,true);
 
   slotClicked(pos_cache[readDirection], pos_cache[phaseDirection], pos_cache[sliceDirection]);
 
@@ -422,17 +442,17 @@ void MiViewView::showTimecourse() {
 
 void MiViewView::showProtocol() {
   file->prot.set_parmode(noedit);
-  new JDXwidgetDialog(file->prot,2,this,false,true);
+  new LDRwidgetDialog(file->prot,2,this,false,true);
 }
 
 
-STD_string MiViewView::check_and_get_format(const STD_string& fname, const svector& possible_formats) {
+STD_string MiViewView::check_and_get_format(const STD_string& fname, const svector& possible_formats, bool show_error_msg) {
   Log<MiViewComp> odinlog("MiViewView","check_and_get_format");
   STD_string result;
-  STD_string format=JDXfileName(fname).get_suffix();
+  STD_string format=LDRfileName(fname).get_suffix();
   for(unsigned int ifmt=0; ifmt<possible_formats.size(); ifmt++) if(possible_formats[ifmt]==format) result=format;
-  if(result=="") {
-    STD_string msg=justificate("File format/extension \'"+format+"\' is not supported. Possible formats are: "+possible_formats.printbody());
+  if(show_error_msg && result=="") {
+    STD_string msg=justificate("File format/extension \'"+format+"\' is not supported. Possible formats are:\n"+possible_formats.printbody(), 0, false, _DEFAULT_LINEWIDTH_/2);
     message_question(msg.c_str(), "Invalid File Format", this, false, true);
   }
   return result;
@@ -555,7 +575,7 @@ void MiViewView::filedata2displaydata() {
       float delta=file->stat.max-file->stat.min;
       ODINLOG(odinlog,normalDebug) << "min/max/delta=" << file->stat.min << "/" << file->stat.max << "/" << delta << STD_endl;
 
-      if(delta<=0.0) {displaydata=JDXfloat(min); return;}
+      if(delta<=0.0) {displaydata=LDRfloat(min); return;}
 
       float brightoffset=mopts.brightness/100.0-0.5;
       float contrfactor=pow(10.0,mopts.contrast/100.0);
