@@ -2,7 +2,7 @@
                           miviewview.h  -  description
                              -------------------
     begin                : Thu Jun 20 19:02:26 CEST 2002
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -18,13 +18,13 @@
 #ifndef MIVIEWVIEW_H
 #define MIVIEWVIEW_H
 
-#include <odinqt/jdxwidget.h>
+#include <odinqt/ldrwidget.h>
 
 
 #include <odinpara/odinpara.h>
-#include <odinpara/jdxnumbers.h>
-#include <odinpara/jdxarrays.h>
-#include <odinpara/jdxblock.h>
+#include <odinpara/ldrnumbers.h>
+#include <odinpara/ldrarrays.h>
+#include <odinpara/ldrblock.h>
 
 // miview modules
 #include "miview_fmri.h"
@@ -44,24 +44,24 @@ class MiViewComp {
 
 ////////////////////////////////////////
 
-struct MiViewOpts : JcampDxBlock {
+struct MiViewOpts : LDRblock {
 
-  JDXbool color;
-  JDXfloat contrast;
-  JDXfloat brightness;
-  JDXstring valfile;
-  JDXstring recfile;
-  JDXint blowup;
-  JDXstring low;
-  JDXstring upp;
-  JDXstring dump;
-  JDXstring mapfile;
-  JDXfloat maplow;
-  JDXfloat mapupp;
-  JDXfloat maprect;
-  JDXstring legendexport;
-  JDXstring maplegendexport;
-  JDXbool noscale;
+  LDRbool color;
+  LDRfloat contrast;
+  LDRfloat brightness;
+  LDRstring valfile;
+  LDRstring recfile;
+  LDRint blowup;
+  LDRstring low;
+  LDRstring upp;
+  LDRstring dump;
+  LDRstring mapfile;
+  LDRfloat maplow;
+  LDRfloat mapupp;
+  LDRfloat maprect;
+  LDRstring legendexport;
+  LDRstring maplegendexport;
+  LDRbool noscale;
 
   MiViewOpts();
 };
@@ -91,6 +91,7 @@ class MiViewView : public QWidget {
 
  public slots:
 
+  void writeData();
   void writeImage();
   void writeROIs();
   void writeFmriClusters();
@@ -123,7 +124,7 @@ class MiViewView : public QWidget {
 
   void filedata2displaydata();
 
-  STD_string check_and_get_format(const STD_string& fname, const svector& possible_formats);
+  STD_string check_and_get_format(const STD_string& fname, const svector& possible_formats, bool show_error_msg=true);
 
   void export_legend(const STD_string& filename);
   void export_map_legend(const STD_string& filename);
@@ -140,11 +141,11 @@ class MiViewView : public QWidget {
 
   FileData* file; // holding the data of the file
 
-  JDXfloatArr displaydata;
+  LDRfloatArr displaydata;
   GuiProps guiprops_cache;
-  JcampDxBlock settings;
-  JDXint repetition;
-  JDXfloatArr timecourse;
+  LDRblock settings;
+  LDRint repetition;
+  LDRfloatArr timecourse;
 
   bool has_olm;
 
@@ -152,18 +153,19 @@ class MiViewView : public QWidget {
   SelectionData* selection;  // holding data of user selections
 
   GuiGridLayout* grid;
-  JDXwidget* displaywidget;
-  JDXwidget* settingswidget;
-  JDXwidget* tcoursewidget;
-  JDXwidget* fmriwidget;
+  LDRwidget* displaywidget;
+  LDRwidget* settingswidget;
+  LDRwidget* tcoursewidget;
+  LDRwidget* fmriwidget;
 
+  STD_string data_fname_cache;
   STD_string image_fname_cache;
   STD_string rois_fname_cache;
   STD_string clusters_fname_cache;
   STD_string profile_fname_cache;
   STD_string tcourse_fname_cache;
 
-  JDXint pos_cache[n_directions];
+  LDRint pos_cache[n_directions];
 
 
   // miview modules
