@@ -2,7 +2,7 @@
                           odin.h  -  description
                              -------------------
     begin                : Sun Sep 28 21:30:11 CEST 2003
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -106,6 +106,7 @@
   * By clicking an item in the list, the Pulsar user interface will pop up to show the
   * parameters of the pulse.
   *
+  * \if Paravision
   * \section brukerMenu Bruker Menu
   * \subsection brukerMenu_ppg Pulse Program
   * Displays the pulse program
@@ -117,7 +118,9 @@
   * Start a pilot scan on the host where Paravision is running
   * \subsection brukerMenu_scan Scan
   * Start a scan (GOP) on host where Paravision is running using the current sequence settings
+  * \endif
   *
+  * \if IDEA_n4
   * \section siemensMenu Siemens Menu
   * \subsection siemensMenu_events Event Table
   * Displays the event blocks and the events therein of the current sequence
@@ -125,10 +128,13 @@
   * Compile the ODIN libraries for sequence design for IDEA so that IDEA DLLs can be exported
   * \subsection siemensMenu_dll Export Siemens DLLs
   * Create all files/objects necessary to create a Siemens sequence DLL which contains all previously selected ODIN sequences
+  * \endif
   *
+  * \if EPIC
   * \section geMenu GE Menu
   * \subsection geMenu_events EPIC Code
   * Generates code for the EPIC framework
+  * \endif
   *
   * \section prefMenu Preferences Menu
   * \subsection prefMenu_sett Settings
@@ -138,13 +144,13 @@
   * \subsection prefMenu_loadsys Load systemInfo
   * Load the system configuration from a file
   * \subsection prefMenu_debug Debugging/Tracing
-  * Change the debugging/tracing settings
+  * Change the debugging/tracing settings.
   * This option is not available if ODIN was compiled as a release
   *
   */
 
 #define IDS_ODIN_ABOUT               "ODIN user interface\nVersion " VERSION \
-                                    "\n(w) 2004 by Thies Jochimsen\n\n" \
+                                    "\n(w) 2004-2015 by Thies Jochimsen\n\n" \
                                     "Compiled with the following plugins:\n" \
                                     PLUGIN_LIBS
 
