@@ -2,7 +2,7 @@
                           odindialog_idea.h  -  description
                              -------------------
     begin                : Fri Mar 9 21:30:11 CEST 2007
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -20,20 +20,20 @@
 
 // Qt related headers first to avoid ambiguity with 'debug'
 #include <qobject.h>
-#include <odinqt/jdxwidget.h>
+#include <odinqt/ldrwidget.h>
 
-#include <odinpara/jdxblock.h>
-#include <odinpara/jdxtypes.h>
-#include <odinpara/jdxnumbers.h>
+#include <odinpara/ldrblock.h>
+#include <odinpara/ldrtypes.h>
+#include <odinpara/ldrnumbers.h>
 
 
 #include "odinconf.h"
 
-struct IdeaOpts : JcampDxBlock {
+struct IdeaOpts : LDRblock {
 
   IdeaOpts();
 
-  void set_defaults(const OdinConf& conf, QWidget *parent);
+  bool set_defaults(const OdinConf& conf, STD_string* errmsg, QWidget *parent);
 
   STD_string get_vxworks_postfix() const;
   STD_string get_vxworks_ext() const;
@@ -44,35 +44,35 @@ struct IdeaOpts : JcampDxBlock {
   STD_string get_odindir_slash() const {return replaceStr(odindir,"\\","/");}
 
 
-  JDXfileName arch;
+  LDRfileName arch;
 
-  JDXfileName ideadir;
-  JDXfileName odindir;
+  LDRfileName ideadir;
+  LDRfileName odindir;
 
-  JDXfileName msvcdir;
+  LDRfileName msvcdir;
 
-  JDXfileName seqdir;
-  JDXstring odin2idea_label;
+  LDRfileName seqdir;
+  LDRstring odin2idea_label;
 
-  JDXfileName icedir;
+  LDRfileName icedir;
 
-  JDXenum vxworks_cpu;
-  JDXint vxworks_heap_size;
-  JDXbool debug_vxworks_host;
+  LDRenum vxworks_cpu;
+  LDRint vxworks_heap_size;
+  LDRbool debug_vxworks_host;
 
-  JDXint make_jobs;
-  JDXbool make_clean;
+  LDRint make_jobs;
+  LDRbool make_clean;
 
 
 
   // read-only settings
-  JDXfileName vxworks_dir;
-  JDXstring vxworks_flags;
-  JDXstring vxworks_opts;
-  JDXfileName vxworks_path;
-  JDXfileName win_cxx;
-  JDXstring hostd_flags;
-  JDXstring host_flags;
+  LDRfileName vxworks_dir;
+  LDRstring vxworks_flags;
+  LDRstring vxworks_opts;
+  LDRfileName vxworks_path;
+  LDRfileName win_cxx;
+  LDRstring hostd_flags;
+  LDRstring host_flags;
 
 };
 
@@ -112,7 +112,7 @@ class IdeaDialog :  public QObject, public GuiDialog {
   GuiButton* pb_cancel;
   GuiButton* pb_defaults;
   GuiButton* pb_compile;
-  JDXwidget* optswidget;
+  LDRwidget* optswidget;
 
 };
 
