@@ -2,7 +2,7 @@
                           odindialog_new.h  -  description
                              -------------------
     begin                : Mon Oct 10 21:30:11 CEST 2005
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -20,7 +20,7 @@
 
 #include <qobject.h>
 
-#include <odinqt/jdxwidget.h>
+#include <odinqt/ldrwidget.h>
 
 
 
@@ -28,7 +28,7 @@ class NewMethDialog : public QObject, public GuiDialog {
  Q_OBJECT
 
  public:
-  NewMethDialog(QWidget *parent, JcampDxBlock& files);
+  NewMethDialog(QWidget *parent, LDRblock& files);
   ~NewMethDialog();
 
  public:
@@ -48,7 +48,7 @@ class NewMethDialog : public QObject, public GuiDialog {
   GuiGridLayout* grid;
   GuiButton*   pb_done;
   GuiButton*   pb_cancel;
-  JDXwidget* fileswidget;
+  LDRwidget* fileswidget;
 };
 
 
