@@ -2,7 +2,7 @@
                           odindialog_system.h  -  description
                              -------------------
     begin                : Sun Oct 2 21:30:11 CEST 2005
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -20,7 +20,7 @@
 
 #include <qobject.h>
 
-#include <odinqt/jdxwidget.h>
+#include <odinqt/ldrwidget.h>
 
 #include <odinpara/system.h>
 
@@ -49,7 +49,7 @@ class SystemDialog : public QObject, public GuiDialog {
   GuiGridLayout* grid;
   enumBox* pf;
   GuiButton* pb_done;
-  JDXwidget* sysInfo_widget;
+  LDRwidget* sysInfo_widget;
 };
 
 #endif
