@@ -14,7 +14,7 @@
 
 #include <odinseq/seqmeth.h>
 
-#include <odinqt/jdxblockwidget.h>
+#include <odinqt/ldrblockwidget.h>
 
 
 
@@ -1073,11 +1073,11 @@ void PlotView::save_current_channel_data() {
 void PlotView::osci() {
   Log<OdinComp> odinlog("PlotView","osci");
 
-  JcampDxBlock oscisettings("Settings for Oscilloscope");
+  LDRblock oscisettings("Settings for Oscilloscope");
   oscisettings.append(TriggerType);
   oscisettings.append(TriggerWidth);
   oscisettings.append(RefreshRate);
-  JDXwidgetDialog* dlg=new JDXwidgetDialog(oscisettings,1,this,true);
+  new LDRwidgetDialog(oscisettings,1,this,true);
 
   markType marktype=markType(int(TriggerType));
 
