@@ -109,12 +109,12 @@ void OdinView::report(bool status, const STD_string& trans_label, const STD_stri
 void OdinView::create_widgets() {
   Log<OdinComp> odinlog("OdinView","create_widgets");
 
-  commpars=new JDXwidget(method->get_commonPars(),1,this,false,(STD_string(method->get_label())+"_").c_str());
+  commpars=new LDRwidget(method->get_commonPars(),1,this,false,(STD_string(method->get_label())+"_").c_str());
   commpars->show();
   grid->add_widget( commpars, 0, 0, GuiGridLayout::Center );
   connect(commpars,SIGNAL(valueChanged()),this,SLOT(recalc_method()));
 
-  seqpars=new JDXwidget(method->get_methodPars(),1,this,false,(STD_string(method->get_label())+"_").c_str());
+  seqpars=new LDRwidget(method->get_methodPars(),1,this,false,(STD_string(method->get_label())+"_").c_str());
   seqpars->show();
   grid->add_widget( seqpars, 0, 1, GuiGridLayout::Center );
   connect(seqpars,SIGNAL(valueChanged()),this,SLOT(recalc_method()));
@@ -141,7 +141,7 @@ void OdinView::delete_widgets() {
 void OdinView::new_method() {
   Log<OdinComp> odinlog("OdinView","new_method");
 
-  JcampDxBlock newmethfiles("NewSequence");
+  LDRblock newmethfiles("NewSequence");
 
   templatemeth.set_label("SequenceTemplate");
   templatemeth.set_defaultdir(settings.get_seqexamplesdir());
@@ -228,13 +228,13 @@ void OdinView::update_methodsel() {
 
 void OdinView::open_method() {
   Log<OdinComp> odinlog("OdinView","open_method");
-  JDXfileName fname=get_open_filename("Open Method", settings.methroot.c_str(), (STD_string(settings.sourcecode.get_label())+" (*."+settings.sourcecode.get_suffix()+")").c_str(), this);
+  LDRfileName fname=get_open_filename("Open Method", settings.methroot.c_str(), (STD_string(settings.sourcecode.get_label())+" (*."+settings.sourcecode.get_suffix()+")").c_str(), this);
   if(fname!="") {
     method.clear();
     settings.sourcecode=STD_string(fname);
 
     // Set methroot accordingly
-    JDXfileName methdir=fname.get_dirname();
+    LDRfileName methdir=fname.get_dirname();
     settings.methroot=STD_string(methdir.get_dirname());
 
     if(chsrcdir()) method.link();
@@ -294,7 +294,7 @@ bool OdinView::create_seqplot(bool for_simulation) {
   pd->set_coilsdir(settings.get_coilsdir());
   pd->get_opts(true,true).load(settings.get_confdir()+SEPARATOR_STR+"plotsimopts");
 
-  JDXwidgetDialog* sidlg=new JDXwidgetDialog(pd->get_opts(true,for_simulation),1,this,true);
+  LDRwidgetDialog* sidlg=new LDRwidgetDialog(pd->get_opts(true,for_simulation),1,this,true);
   ODINLOG(odinlog,normalDebug) << "sidlg=" << sidlg << STD_endl;
 
   // store new config
@@ -682,7 +682,7 @@ void OdinView::epiccode() {
 
 void OdinView::edit_prefs() {
   Log<OdinComp> odinlog("OdinView","edit_prefs");
-  JDXwidgetDialog* dlg=new JDXwidgetDialog(settings,2,this);
+  LDRwidgetDialog* dlg=new LDRwidgetDialog(settings,2,this);
   connect(dlg,SIGNAL(finished()),this,SLOT(react_on_changed_prefs()));
 }
 
@@ -697,7 +697,7 @@ void OdinView::edit_system() {
 
 void OdinView::edit_study() {
   Log<OdinComp> odinlog("OdinView","edit_study");
-  JDXwidgetDialog* dlg=new JDXwidgetDialog(method->get_studyInfo(),2,this);
+  LDRwidgetDialog* dlg=new LDRwidgetDialog(method->get_studyInfo(),2,this);
   connect(dlg,SIGNAL(finished()),this,SLOT(react_on_changed_prefs()));
 }
 
@@ -742,7 +742,7 @@ int OdinView::load_prefs(bool ignore_debugLevels) {
   ODINLOG(odinlog,normalDebug) << "retval=" << retval << STD_endl;
   change_debugger();
 
-  ideaopts->set_defaults(settings,0); // do not ask for IDEA directory
+  ideaopts->set_defaults(settings,0,0); // do not ask for IDEA directory and ignore errors
   ideaopts->load(settings.get_confdir()+SEPARATOR_STR+"ideaopts");
 
   return retval;
@@ -776,7 +776,7 @@ int OdinView::save_prefs() {
   ideaopts->write(settings.get_confdir()+SEPARATOR_STR+"ideaopts");
 
   ODINLOG(odinlog,normalDebug) << "saving settings" << STD_endl;
-  JcampDxBlock prefs;
+  LDRblock prefs;
   prefs.merge(settings);
   return prefs.write(settings.get_confdir()+SEPARATOR_STR+"settings");
 }
@@ -822,7 +822,9 @@ void OdinView::compile_idea() {
 
 
 void OdinView::export_dlls() {
-  JDXfileName testfile(ideaopts->odindir+SEPARATOR_STR+"build_complete_tag");
+  Log<OdinComp> odinlog("OdinView","export_dlls");
+  LDRfileName testfile(ideaopts->odindir+SEPARATOR_STR+"build_complete_tag");
+  ODINLOG(odinlog,normalDebug) << "testfile=>" << testfile << "<" << STD_endl;
   if(!testfile.exists()) {
     message_question(justificate("Cannot find compiled ODIN for IDEA installation under "+ideaopts->odindir+". Please create it first using the following dialog.").c_str(), "ODIN for IDEA not found", this, false, true);
     compile_idea();
