@@ -56,7 +56,7 @@ class ComplexDataTest : public UnitTest {
 
     ComplexData<2> testarray(testsize,testsize);
     TinyVector<int,2> index;
-    for(int i=0; i<testarray.numElements(); i++) {
+    for(unsigned int i=0; i<testarray.numElements(); i++) {
       index=testarray.create_index(i);
       float radius=norm(index(0)-testsize/2-1,index(1)-testsize/2+2); // off-center disk
       if(radius<4.0) testarray(index)=STD_complex(2.0,0.0);
