@@ -2,7 +2,7 @@
                           complexdata.h  -  description
                              -------------------
     begin                : Fri Apr 6 2001
-    copyright            : (C) 2000-2014 by Thies Jochimsen & Michael von Mengershausen
+    copyright            : (C) 2000-2015 by Thies Jochimsen & Michael von Mengershausen
     email                : thies@jochimsen.de  mengers@cns.mpg.de
  ***************************************************************************/
 
@@ -277,7 +277,7 @@ void ComplexData<N_rank>::modulate_offset(const TinyVector<float,N_rank>& rel_of
   Log<OdinData> odinlog("ComplexData","modulate_offset");
 
   TinyVector<int, N_rank> index;
-  for(int i=0; i<Array<STD_complex,N_rank>::numElements(); i++) {
+  for(unsigned int i=0; i<Array<STD_complex,N_rank>::numElements(); i++) {
     index=Data<STD_complex,N_rank>::create_index(i);
     (*this)(index)*=exp(float2imag(-2.0*PII*sum(rel_offset*index)));
   }
@@ -314,8 +314,6 @@ void ComplexData<N_rank>::shift_subpixel(const TinyVector<float,N_rank>& shiftve
 template <int N_rank>
 Data<float,N_rank> ComplexData<N_rank>::phasemap() const {
 
-  Range all=Range::all();
-
   const ComplexData<N_rank>& indata=*this;
 
   TinyVector<int,N_rank> myshape(indata.shape());
