@@ -2,7 +2,7 @@
                           data.h  -  description
                              -------------------
     begin                : Fri Apr 6 2001
-    copyright            : (C) 2000-2014 by Thies Jochimsen & Michael von Mengershausen
+    copyright            : (C) 2000-2015 by Thies Jochimsen & Michael von Mengershausen
     email                : thies@jochimsen.de  mengers@cns.mpg.de
  ***************************************************************************/
 
@@ -599,7 +599,7 @@ int Data<T,N_rank>::write(const STD_string& filename, fopenMode mode) const {
   Log<OdinData> odinlog("Data","write");
   if(filename=="") return 0;
 
-  FILE* file_ptr=FOPEN(filename.c_str(),modestring(mode));
+  FILE* file_ptr=ODIN_FOPEN(filename.c_str(),modestring(mode));
 
   if(file_ptr==NULL) {
     ODINLOG(odinlog,errorLog) << "unable to create/open file >" << filename << "< - " << lasterr() << STD_endl;
@@ -648,7 +648,7 @@ int Data<T,N_rank>::write_asc_file(const STD_string& filename, const Array<T,N_r
 
   Data<T,N_rank> pre_data(pre);
   Data<T,N_rank> post_data(post);
-  int n=Array<T,N_rank>::numElements();
+  unsigned int n=Array<T,N_rank>::numElements();
 
   if(pre_data.numElements()==n) have_pre=true;
   if(post_data.numElements()==n) have_post=true;
@@ -658,7 +658,7 @@ int Data<T,N_rank>::write_asc_file(const STD_string& filename, const Array<T,N_r
 
   T val;
 
-  for(int i=0; i<n; i++) {
+  for(unsigned int i=0; i<n; i++) {
     if(have_pre) {
       val=pre_data(pre_data.create_index(i));
       ofs << val << " ";
@@ -684,7 +684,7 @@ int Data<T,N_rank>::read_asc_file(const STD_string& filename) {
   if(ifs.bad()) return -1;
 
   STD_string valstr;
-  for(int i=0; i<Array<T,N_rank>::numElements(); i++) {
+  for(unsigned int i=0; i<Array<T,N_rank>::numElements(); i++) {
     if(ifs.bad()) return -1;
     ifs >> valstr;
     TypeTraits::string2type(valstr,(*this)(create_index(i)));
@@ -821,7 +821,7 @@ void Data<T,N_rank>::shift(unsigned int shift_dim, int shift) {
   Data<T,N_rank> data_copy(Array<T,N_rank>::copy());
 
   TinyVector<int,N_rank> index;
-  for(int i=0; i<Array<T,N_rank>::numElements(); i++) {
+  for(unsigned int i=0; i<Array<T,N_rank>::numElements(); i++) {
     index=create_index(i);
     T val=data_copy(index);
     int shiftindex=index(shift_dim)+shift;
