@@ -38,7 +38,7 @@ struct Iris3DFormat : public FileFormat {
   int write(const Data<float,4>& data, const STD_string& filename, const FileWriteOpts& opts, const Protocol& prot) {
     Log<FileIO> odinlog("Iris3DFormat","write");
 
-    FILE *out=FOPEN( filename.c_str(), "w");
+    FILE *out=ODIN_FOPEN( filename.c_str(), "w");
     if(!out){
       ODINLOG(odinlog,errorLog) << "could not open "<< filename <<" for writing"<< STD_endl;
       return -1;
@@ -50,12 +50,12 @@ struct Iris3DFormat : public FileFormat {
     const dvector center(prot.geometry.get_center());
 
     const i3Dblock head={
-      data_shape[3],data_shape[2],data_shape[1],
+      short(data_shape[3]),short(data_shape[2]),short(data_shape[1]),
       1,
-      center[0],center[2],center[2],
+      float(center[0]),float(center[2]),float(center[2]),
       voxel_extent(prot.geometry,readDirection, data.extent(3)),
       voxel_extent(prot.geometry,phaseDirection, data.extent(2)),
-      prot.geometry.get_sliceDistance()
+      float(prot.geometry.get_sliceDistance())
     };
 
     fwrite(&head,sizeof(i3Dblock),1,out);
