@@ -51,6 +51,12 @@
 #define DCM_PAT_WEIGHT DCM_PatientWeight
 #endif
 
+#ifdef DCM_PatientsSize
+#define DCM_PAT_SIZE DCM_PatientsSize
+#else
+#define DCM_PAT_SIZE DCM_PatientSize
+#endif
+
 #ifdef DCM_PatientsAge
 #define DCM_PAT_AGE DCM_PatientsAge
 #else
@@ -144,16 +150,18 @@ template<typename T> void copy(const DiPixel *pix, Data<float,4> &dst,const Tiny
 }
 
 template<typename BASE,typename DST> DST endian(const BASE *b){
+  Log<FileIO> odinlog("DicomFormat","endian");
   DST ret=0;
 #if __BYTE_ORDER == __LITTLE_ENDIAN
-  for(short i=0;i<(short)sizeof(DST);i++)
+  for(short i=0;i<(short)sizeof(DST);i++) {
 #elif __BYTE_ORDER == __BIG_ENDIAN
-  for(short i=(short)sizeof(DST)-1;i>=0;i--)
+  for(short i=(short)sizeof(DST)-1;i>=0;i--) {
 #else
-#error "Sorry your endianess is not supported. What the heck are you comiling on ??"
+#error __BYTE_ORDER undefined
 #endif
+    ODINLOG(odinlog,normalDebug) << "b[" << i << "]" << int(b[i]) << STD_endl;
     ret+=b[i]<<i*8;
-
+  }
   return ret;
 }
 
@@ -161,6 +169,8 @@ template<typename BASE,typename DST> DST endian(const BASE *b){
 svector fetch_from_MR_CSA_Header(DcmElement* csaHeader, STD_string label){
   Log<FileIO> odinlog("DicomFormat","fetch_from_MR_CSA_Header");
 
+  ODINLOG(odinlog,normalDebug) << "csaHeader->getLength()=" << csaHeader->getLength() << STD_endl;
+
   svector ret;
   Uint8 *array;
   csaHeader->getUint8Array(array);
@@ -170,11 +180,18 @@ svector fetch_from_MR_CSA_Header(DcmElement* csaHeader, STD_string label){
     if(found==STD_string::npos) {
       pos+=dummy.length()+1;
     } else {
+      ODINLOG(odinlog,normalDebug) << "found >" << label << "< at pos=" << pos << STD_endl;
       pos+=found+0x40; //len of the name is 0x20 plus 0x20 "I dont know what the hell this is supposed to be"
+      int markval=array[pos]; // supposed to be 0x01 at this position for usable values
+      if(markval!=0x01) {
+        ODINLOG(odinlog,normalDebug) << "markval=" << markval << STD_endl;
+        break; // integrity check
+      }
       /*Sint32 &vm=*((Sint32*)array+pos);*/pos+=sizeof(Sint32);
       /*char *vr=(char*)array+pos;*/pos+=0x4;
       /*Sint32 syngodt=endian<Uint8,Uint32>(array+pos);*/pos+=sizeof(Sint32);
       Sint32 nitems=endian<Uint8,Uint32>(array+pos);pos+=sizeof(Sint32);
+      ODINLOG(odinlog,normalDebug) << "nitems=" << nitems << STD_endl;
       if(nitems) {
         pos+=sizeof(Sint32); //77
         Sint32 len=0;
@@ -185,16 +202,19 @@ svector fetch_from_MR_CSA_Header(DcmElement* csaHeader, STD_string label){
           const unsigned s=ret.size();ret.resize(s+1);
           ret[s]=STD_string((char*)array+pos);//store the text if the is some
           pos+=((len+sizeof(Sint32)-1)/sizeof(Sint32))*sizeof(Sint32);//increment pos by len aligned to sizeof(Sint32)
+          if(pos>csaHeader->getLength()) { // integrity check
+             ODINLOG(odinlog,normalDebug) << "pos out of bounds" << STD_endl;
+             break;
+          }
         }
         ODINLOG(odinlog,normalDebug) << "Found \""+label+"\" in CSA header: \"" << ret.printbody() << "\"" << STD_endl;
-
       } else {
         ODINLOG(odinlog,normalDebug) << "Found empty \""+label+"\" in CSA header" << STD_endl;
       }
       return ret;
     }
   }
-  ODINLOG(odinlog,normalDebug) << "Could not find\""+label+"\" in CSA header: " << STD_endl;
+  ODINLOG(odinlog,normalDebug) << "Could not find usable field \""+label+"\" in CSA header" << STD_endl;
 
   return ret;
 }
@@ -237,13 +257,11 @@ struct DicomFormat : public FileFormat {
 
     ODINLOG(odinlog,normalDebug) << "filename=" << filename << STD_endl;
 
-    Range all=Range::all();
-
     const char* func="DicomFormat::read";
     if(check_dict(func)) return -1;
 
 
-    if(JDXfileName(filename).get_basename()=="DICOMDIR") return 0; // ignore DICOMDIR
+    if(LDRfileName(filename).get_basename()=="DICOMDIR") return 0; // ignore DICOMDIR
 
 #ifdef OFLOG_H
     OFLog::configure(OFLogger::WARN_LOG_LEVEL); // reset logging (in dcmtk 3.6.0 info logging is somehow enabled sometimes)
@@ -265,22 +283,61 @@ struct DicomFormat : public FileFormat {
     DcmElement* csaHeader=0;
     if(dset->findAndGetElement(DcmTagKey(0x0029,0x1010),csaHeader).good()) {
       ODINLOG(odinlog,normalDebug) << "found Siemens-specific CSA Header" << STD_endl;
+
 /*
+      // write headers to file for debugging
       Uint8* array=0;
       csaHeader->getUint8Array(array);
       if(array) {
-        DcmElement* csaData=0;
-        if(dset->findAndGetElement(DcmTagKey(0x7fe1,0x1010),csaData).good()) {
-          ODINLOG(odinlog,infoLog) << "csaData->getLength()=" << csaData->getLength() << STD_endl;
-
-          STD_string csaHeaderStr((const char*)array, csaHeader->getLength());
-          STD_cout << csaHeaderStr << STD_endl;
-        }
+        FILE* fp=fopen("/tmp/csa", "w");
+        fwrite(array, sizeof(Uint8), csaHeader->getLength(),fp);
+        fclose(fp);
       }
 */
+     }
+
+     DcmElement* csaSeriesHeader=0;
+     if(dset->findAndGetElement(DcmTagKey(0x0029,0x1020),csaSeriesHeader).good()) {
+       ODINLOG(odinlog,normalDebug) << "found Siemens-specific CSA Series Header" << STD_endl;
+
+       Uint8* serarray=0;
+       csaSeriesHeader->getUint8Array(serarray);
+
+
+      if(serarray) {
+
+/*      // XProtocol stuff
+        const char* findpattern="<XProtocol>";
+        unsigned int findlength=STD_string(findpattern).length();
+
+        STD_list<unsigned int> poslist;
+        for(unsigned int ipos=0; ipos<=(csaSeriesHeader->getLength()-findlength); ipos++) {
+          bool found=true;
+          for(unsigned int ilength=0; ilength<findlength; ilength++) {
+            if(serarray[ipos+ilength]!=findpattern[ilength]) {
+              found=false;
+              break;
+            }
+          }
+          if(found) {
+            poslist.push_back(ipos);
+            ODINLOG(odinlog,normalDebug) << "found " << findpattern << " at pos=" << ipos << STD_endl;
+          }
+        }
+*/
+
+/*
+          // write headers to file for debugging
+          FILE* fp=fopen("/tmp/csaser", "w");
+          fwrite(serarray, sizeof(Uint8), csaSeriesHeader->getLength(),fp);
+          fclose(fp);
+*/
+      }
     }
 
 
+
+
     DicomImage img(dset, EXS_Unknown, CIF_IgnoreModalityTransformation); // apply modality transform manually to get higher floating point accuracy
 
     EI_Status status=img.getStatus();
@@ -354,7 +411,7 @@ struct DicomFormat : public FileFormat {
     }
     //@todo fallback for GE/Philips
     if(foundB.good()){//we got the b_value
-      JDXtriple bvector(0,0,0,"Diffusion_bVector");
+      LDRtriple bvector(0,0,0,"Diffusion_bVector");
       if(Bvalue){
         const Float64 *dir;unsigned long count;
         OFCondition foundD=dset->findAndGetFloat64Array(DCM_DiffusionGradientOrientation,dir,&count); //in case someone actually used the right Tag
@@ -468,7 +525,11 @@ struct DicomFormat : public FileFormat {
     if(!check_status(func,"PatientsWeight",dset->findAndGetOFString(DCM_PAT_WEIGHT, valstr),warning)) {
       if(valstr.length()) pweight=atof(valstr.c_str());
     }
-    prot.study.set_Patient(pid, pname, pdbirth, psex, pweight);
+    float psize=2000.0;
+    if(!check_status(func,"PatientsSize",dset->findAndGetOFString(DCM_PAT_SIZE, valstr),warning)) {
+      if(valstr.length()) psize=1000.0*atof(valstr.c_str());
+    }
+    prot.study.set_Patient(pid, pname, pdbirth, psex, pweight, psize);
 
 
     // Get study stuff
@@ -616,6 +677,12 @@ struct DicomFormat : public FileFormat {
         prot.system.set_transmit_coil_name(valstr.c_str());
       }
 
+      if(csaHeader) {
+        svector imacoils=fetch_from_MR_CSA_Header(csaHeader,"ImaCoilString");
+        prot.system.set_receive_coil_name(imacoils.printbody());
+      }
+
+
       // Sequence stuff
       if(!check_status(func,"PixelBandwidth",dset->findAndGetOFString(DCM_PixelBandwidth, valstr),warning)) {
         prot.seqpars.set_AcqSweepWidth(0.001*atof(valstr.c_str())*shape(3));
@@ -701,7 +768,7 @@ struct DicomFormat : public FileFormat {
     const char* func="DicomFormat::write";
     if(check_dict(func)) return -1;
 
-    JDXfileName fname(filename);
+    LDRfileName fname(filename);
 
 #ifdef OFLOG_H
     OFLog::configure(OFLogger::WARN_LOG_LEVEL); // reset logging (in dcmtk 3.6.0 info logging is somehow enabled sometimes)
@@ -709,7 +776,7 @@ struct DicomFormat : public FileFormat {
 
     // Create directory to store DICOMS
     DicomDirInterface dicomdir;
-    JDXfileName dstdir; dstdir.set_dir(true);
+    LDRfileName dstdir; dstdir.set_dir(true);
     dstdir=fname.get_dirname()+SEPARATOR_STR+fname.get_basename_nosuffix()+STD_string("_dcm");
     if( createdir(dstdir.c_str()) && (!checkdir(dstdir.c_str())) ) {
       ODINLOG(odinlog,errorLog) << "Cannot create directoy " << dstdir << STD_endl;
@@ -770,8 +837,8 @@ struct DicomFormat : public FileFormat {
       STD_string pid;
       STD_string pdbirth;
       char psex;
-      float pweight;
-      prot.study.get_Patient(pid, pname, pdbirth, psex, pweight);
+      float pweight, psize;
+      prot.study.get_Patient(pid, pname, pdbirth, psex, pweight, psize);
       pdbirth[ODIN_DATE_LENGTH]='\0';
       pname=replaceStr(pname," ","^");
       if(pid=="") pid="Zero"; // dicomdir.addDicomFile does not like zero-size string
@@ -780,6 +847,7 @@ struct DicomFormat : public FileFormat {
       if(check_status(func,"PatientsBirthDate", dataset->putAndInsertString(DCM_PAT_BIRTHDATE, pdbirth.c_str()))) return -1;
       if(check_status(func,"PatientsSex",       dataset->putAndInsertString(DCM_PAT_SEX,       STD_string(1,psex).c_str()))) return -1;
       if(check_status(func,"PatientsWeight",    dataset->putAndInsertString(DCM_PAT_WEIGHT,    ftos(pweight).c_str()))) return -1;
+      if(check_status(func,"PatientsSize",      dataset->putAndInsertString(DCM_PAT_SIZE,      ftos(0.001*psize).c_str()))) return -1;
 
       // Calculate patient age in years
       int ibirth=atoi(pdbirth.c_str());
@@ -891,9 +959,9 @@ struct DicomFormat : public FileFormat {
 
 
       // DTI
-      JcampDxClass* bptr=prot.get_parameter("Diffusion_bVector");
+      LDRbase* bptr=prot.get_parameter("Diffusion_bVector");
       if(bptr) {
-        JDXtriple* bvec=0;
+        LDRtriple* bvec=0;
         bvec=bptr->cast(bvec);
         if(bvec) {
           fvector fbvec(*bvec);
