@@ -86,7 +86,7 @@ struct GzipFormat : public FileFormat
   bool file_compress(STD_string infile, STD_string outfile) {
     Log<FileIO> odinlog("GzipFormat","file_compress");
     STD_ifstream in(infile.c_str(), ios::binary);
-    if (in == NULL) {
+    if (in.bad()) {
       ODINLOG(odinlog,errorLog) << infile.c_str() << STD_endl;
       return false;
     }
@@ -152,7 +152,7 @@ struct GzipFormat : public FileFormat
   }
 
   static STD_string tempfilename(STD_string filename) {
-    const STD_string unzipped_suffix=JDXfileName(JDXfileName(filename).get_basename_nosuffix()).get_suffix();
+    const STD_string unzipped_suffix=LDRfileName(LDRfileName(filename).get_basename_nosuffix()).get_suffix();
     return tempfile()+"."+unzipped_suffix;
   }
 
@@ -189,7 +189,7 @@ struct GzipFormat : public FileFormat
         rmfile(tmpfile.c_str());
       }
       else {
-        const JDXfileName fname(filename);
+        const LDRfileName fname(filename);
         STD_string realname = fname.get_dirname() + SEPARATOR_STR +fname.get_basename_nosuffix();
         ODINLOG(odinlog,infoLog) << " saving " << realname << STD_endl;
         movefile(tmpfile.c_str(), realname.c_str());
