@@ -114,7 +114,7 @@ struct MatlabBinFormat : public FileFormat
       ptr[i]=vect[i];
     return arr;
   }
-  mxArray* triple2Array(const JDXtriple triple) {
+  mxArray* triple2Array(const LDRtriple triple) {
     Log<FileIO> odinlog("MatlabBinFormat","triple2Array");
     mxArray *arr=createMetaDataArray(3);
     if(!arr) {
@@ -259,7 +259,7 @@ struct MatlabBinFormat : public FileFormat
     mxSetField(root, index, "voxel", dat2mat(pair,opts));
     mxSetField(root, index, "center",vector2Array(pair.first.geometry.get_center()));
     mxSetField(root, index, "rotation",rotMatrix2Array(pair.first.geometry.get_gradrotmatrix()));
-    JDXtriple *diff=dynamic_cast<JDXtriple *>(const_cast<Protocol&>(pair.first).methpars.get_parameter("Diffusion_bVector"));
+    LDRtriple *diff=dynamic_cast<LDRtriple *>(const_cast<Protocol&>(pair.first).methpars.get_parameter("Diffusion_bVector"));
     if(diff)mxSetField(root, index, "bVector",triple2Array(*diff));
   }
   int write(const FileIO::ProtocolDataMap& pdmap, const STD_string& filename, const FileWriteOpts& opts) {
