@@ -12,9 +12,9 @@ FileReadOpts::FileReadOpts() {
   format.set_cmdline_option("rf").set_description("Read format, use it to override file extension");
   append_member(format,"format");
 
-  jdx="";
-  jdx.set_cmdline_option("jdx").set_description("If multiple JDX arrays are present, select this");
-  append_member(jdx,"jdx");
+  ldr="";
+  ldr.set_cmdline_option("ldr").set_description("If multiple LDR (labeled data record) arrays are present, select this");
+  append_member(ldr,"ldr");
 
 
   cplx.add_item("none");
