@@ -2,7 +2,7 @@
                           filter_align.h  -  description
                              -------------------
     begin                : Fri Jan 16 2009
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -22,8 +22,8 @@
 
 class FilterAlign : public FilterStep {
 
-  JDXfileName fname;
-  JDXint      blowup;
+  LDRfileName fname;
+  LDRint      blowup;
 
   STD_string label() const {return "align";}
   STD_string description() const {return "Align data to the geometry (voxel locations) of an external file";}
