@@ -2,7 +2,7 @@
                           filter_scale.h  -  description
                              -------------------
     begin                : Thu Jan 31 2008
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -22,7 +22,7 @@
 
 class FilterMin : public FilterStep {
 
-  JDXfloat thresh;
+  LDRfloat thresh;
 
   STD_string label() const {return "min";}
   STD_string description() const {return "Clip all values below mininum value";}
@@ -35,7 +35,7 @@ class FilterMin : public FilterStep {
 
 class FilterMax : public FilterStep {
 
-  JDXfloat thresh;
+  LDRfloat thresh;
 
   STD_string label() const {return "max";}
   STD_string description() const {return "Clip all values above maximum value";}
@@ -48,7 +48,7 @@ class FilterMax : public FilterStep {
 
 class FilterType : public FilterStep {
 protected:
-  JDXstring type;
+  LDRstring type;
   float getThresh(bool upper)const;
   void init();
 };
