@@ -2,7 +2,7 @@
                           filter_detrend.h  -  description
                              -------------------
     begin                : Sun May 17 2009
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -22,8 +22,8 @@
 
 class FilterDeTrend : public FilterStep {
 
-  JDXint nlow;
-  JDXbool zeromean;
+  LDRint nlow;
+  LDRbool zeromean;
 
   STD_string label() const {return "detrend";}
   STD_string description() const {return "Remove slow drift over time";}
