@@ -2,7 +2,7 @@
                           filter_edit.h  -  description
                              -------------------
     begin                : Thu Jan 30 2014
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -23,8 +23,8 @@
 
 class FilterEdit : public FilterStep {
 
-  JDXstring pos;
-  JDXfloat val;
+  LDRstring pos;
+  LDRfloat val;
 
 
   STD_string label() const {return "edit";}
