@@ -2,7 +2,7 @@
                           filter_lowpass.h  -  description
                              -------------------
     begin                : Thu Apr 22 2010
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -22,7 +22,7 @@
 
 class FilterLowPass : public FilterStep {
 
-  JDXfloat freq;
+  LDRfloat freq;
 
 
   STD_string label() const {return "lowpass";}
