@@ -62,6 +62,21 @@ class FilterQuantilMask : public FilterStep {
 };
 
 
+///////////////////////////////////////////////////////////////////////////
+
+class FilterSphereMask : public FilterStep {
+
+  LDRstring pos;
+  LDRfloat radius;
+
+  STD_string label() const {return "spheremask";}
+  STD_string description() const {return "Create spherical mask";}
+  bool process(Data<float,4>& data, Protocol& prot) const;
+  FilterStep*  allocate() const {return new FilterSphereMask();}
+  void init();
+};
+
+
 ///////////////////////////////////////////////////////////////////////////
 
 class FilterUseMask : public FilterStep {
