@@ -2,7 +2,7 @@
                           filter_range.h  -  description
                              -------------------
     begin                : Tue Jan 29 2008
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -27,7 +27,7 @@ bool str2range(const STD_string& str, Range& range, int srcsize);
 template<int Dir>
 class FilterRange : public FilterStep {
 
-  JDXstring range;
+  LDRstring range;
 
   STD_string label() const {return STD_string(1,STD_string(dataDimLabel[Dir])[0])+"range";} // Use only 1st letter
   STD_string description() const {return "Select range in "+STD_string(dataDimLabel[Dir])+" direction";}
