@@ -16,7 +16,7 @@
 
 class FilterReSlice : public FilterStep
 {
-  JDXenum orient;
+  LDRenum orient;
   STD_string label() const {return "reslice";}
   STD_string description() const {return "reslices the image to a given orientation";}
   bool process(Data<float,4>& data, Protocol& prot)const;
@@ -28,7 +28,7 @@ class FilterReSlice : public FilterStep
 
 class FilterSwapdim : public FilterStep
 {
-  JDXstring newread,newphase,newslice;
+  LDRstring newread,newphase,newslice;
 
   STD_string label() const {return "swapdim";}
   STD_string description() const {return "swap/reflect dimensions by specifying a direction triple with optional reflection sign appended";}
