@@ -2,7 +2,7 @@
                           filter_rot.h  -  description
                              -------------------
     begin                : Sun Jan 20 2008
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -22,8 +22,8 @@
 
 class FilterRot : public FilterStep {
 
-  JDXdouble angle;
-  JDXdouble kernel;
+  LDRdouble angle;
+  LDRdouble kernel;
 
   STD_string label() const {return "rot";}
   STD_string description() const {return "In-plane rotation";}
