@@ -2,7 +2,7 @@
                           filter_scale.h  -  description
                              -------------------
     begin                : Thu Jan 31 2008
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -22,8 +22,8 @@
 
 class FilterScale : public FilterStep {
 
-  JDXfloat slope;
-  JDXfloat offset;
+  LDRfloat slope;
+  LDRfloat offset;
 
   STD_string label() const {return "scale";}
   STD_string description() const {return "Rescale image values";}
