@@ -2,7 +2,7 @@
                           filter_slicetime.h  -  description
                              -------------------
     begin                : Fri Aug 3 2012
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -22,7 +22,7 @@
 
 class FilterSliceTime : public FilterStep {
 
-  JDXstring sliceorderstr;
+  LDRstring sliceorderstr;
 
   STD_string label() const {return "slicetime";}
   STD_string description() const {return "Correct for different acquisition time points of slices";}
