@@ -2,7 +2,7 @@
                           filter_splice.h  -  description
                              -------------------
     begin                : Fri Feb 17 2012
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -21,7 +21,7 @@
 #include <odindata/filter_step.h>
 
 class FilterSplice: public FilterStep {
-  JDXenum dir;
+  LDRenum dir;
   STD_string label() const {return "splice";}
   STD_string description() const {return "splices the image in the given direction";}
   bool process(FileIO::ProtocolDataMap& pdmap)const;
