@@ -2,7 +2,7 @@
                           filter_tile.h  -  description
                              -------------------
     begin                : Wed Nov 5 2008
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -22,7 +22,7 @@
 
 class FilterTile : public FilterStep {
 
-  JDXint cols;
+  LDRint cols;
 
   STD_string label() const {return "tile";}
   STD_string description() const {return "Combine slices into a square 2D image";}
