@@ -107,6 +107,7 @@ int FunctionFitDerivative_func_fdf (const gsl_vector * gv, void *params, gsl_vec
 
 
 bool FunctionFitDerivative::init(ModelFunction& model_func, unsigned int nvals) {
+  Log<OdinData> odinlog("FunctionFitDerivative","init");
 
   data4fit= new ModelData(nvals);
 
@@ -114,8 +115,10 @@ bool FunctionFitDerivative::init(ModelFunction& model_func, unsigned int nvals)
 
   gsldata=new GslData4Fit;
 
-  // allocate and initialize GSL stuff
   unsigned int npars=model_func.numof_fitpars();
+  ODINLOG(odinlog,normalDebug) << "npars=" << npars << STD_endl;
+
+  // allocate and initialize GSL stuff
   gsldata->covar  = gsl_matrix_alloc (npars, npars);
   gsldata->solver = gsl_multifit_fdfsolver_alloc (gsl_multifit_fdfsolver_lmsder, data4fit->n, npars);
   
@@ -164,7 +167,7 @@ bool FunctionFitDerivative::fit(const Array<float,1>& yvals,
 
   ModelFunction* func=data4fit->modelfunc;
   unsigned int npars=func->numof_fitpars();
-  ODINLOG(odinlog,normalDebug) << "n/numof_fitpars=" << data4fit->n << "/" <<  npars << STD_endl;
+  ODINLOG(odinlog,normalDebug) << "n/npars=" << data4fit->n << "/" <<  npars << STD_endl;
 
   // copy Blitz arrays to data4fit
   for (unsigned long i=0;i<data4fit->n;i++) {
@@ -219,7 +222,30 @@ bool FunctionFitDerivative::fit(const Array<float,1>& yvals,
     return false;
   }
 
-  gsl_multifit_covar (gsldata->solver->J, 0.0, gsldata->covar);
+
+  gsl_matrix* J=0;
+#ifdef HAVE_GSL_MULTIFIT_FDFSOLVER_JAC // for GSL2
+  ODINLOG(odinlog,normalDebug) << "solver->f->size=" << gsldata->solver->f->size << STD_endl;
+  ODINLOG(odinlog,normalDebug) << "solver->x->size=" << gsldata->solver->x->size << STD_endl;
+  J = gsl_matrix_alloc(gsldata->solver->f->size, gsldata->solver->x->size);
+  status = gsl_multifit_fdfsolver_jac(gsldata->solver, J);
+  if(status!=GSL_SUCCESS) {
+    ODINLOG(odinlog,errorLog) << gsl_strerror(status) << STD_endl;
+    return false;
+  }
+#else // pre GSL2
+  J=gsldata->solver->J;
+#endif
+
+  status = gsl_multifit_covar(J, 0.0, gsldata->covar);
+  if(status!=GSL_SUCCESS) {
+    ODINLOG(odinlog,errorLog) << gsl_strerror(status) << STD_endl;
+    return false;
+  }
+
+#ifdef HAVE_GSL_MULTIFIT_FDFSOLVER_JAC // for GSL2
+  gsl_matrix_free(J);
+#endif
 
   // copy results
   for(unsigned int i=0;i<npars;i++) {
@@ -391,7 +417,7 @@ bool LinearFunction::fit(const Array<float,1>& yvals,
 
   m=c=fitpar(); // reset
 
-  int n=yvals.size();
+  unsigned int n=yvals.size();
   ODINLOG(odinlog,normalDebug) << "n=" << n << STD_endl;
 
 
@@ -421,7 +447,7 @@ bool LinearFunction::fit(const Array<float,1>& yvals,
   else s=1.0;
 
   if(haveXvals) x=xvals;
-  else for(int i=0; i<n; i++) x(i)=float(i);
+  else for(unsigned int i=0; i<n; i++) x(i)=float(i);
 
   if(n==2) {
     m.val=secureDivision(yvals(1)-yvals(0), x(1)-x(0));
@@ -646,7 +672,7 @@ bool FunctionFitDownhillSimplex::fit(const Array<float,1>& yvals,
     }
     xvals_cache=xvals;
   } else {
-    for(int i=0; i<xvals_cache.size(); i++) xvals_cache(i)=i;
+    for(unsigned int i=0; i<xvals_cache.size(); i++) xvals_cache(i)=i;
   }
 
   unsigned int npars=numof_fitpars();
@@ -670,7 +696,7 @@ bool FunctionFitDownhillSimplex::fit(const Array<float,1>& yvals,
     RandomDist rd;
 
     for(int irun=0; irun<nruns; irun++) {
-      for(int i=0; i<yvals_cache.size(); i++) yvals_cache(i)=yvals_cache_orig(i)+rd.gaussian(ysigma_cache(i));
+      for(unsigned int i=0; i<yvals_cache.size(); i++) yvals_cache(i)=yvals_cache_orig(i)+rd.gaussian(ysigma_cache(i));
 
       fvector mcminvec=ds->get_minimum_parameters(starting_point, step_size, max_iterations, tolerance);
       for(unsigned int ipar=0; ipar<npars; ipar++) fitpar_ensemble[ipar](irun)=mcminvec[ipar];
@@ -716,7 +742,7 @@ float FunctionFitDownhillSimplex::evaluate(const fvector& pars) const {
 
   for(unsigned int ipar=0; ipar<npars; ipar++) func->get_fitpar(ipar).val=pars[ipar];
 
-  for(int i=0; i<xvals_cache.size(); i++) {
+  for(unsigned int i=0; i<xvals_cache.size(); i++) {
     float f=func->evaluate_f(xvals_cache(i));
     result+=pow(f-yvals_cache(i),2);
   }
@@ -844,7 +870,9 @@ class FunctionFitTest : public UnitTest {
 
       // arbitrary values for testing
       float A_expected=44.5;
+      float A_err_expected=0.0124275;
       float lambda_expected=0.78;
+      float lambda_err_expected=0.000184347;
 
       expf.A.val=A_expected;
       expf.lambda.val=lambda_expected;
@@ -868,14 +896,16 @@ class FunctionFitTest : public UnitTest {
         return false;
       }
 
-      int digits=2;
-      STD_string A_str              =ftos(expf.A.val,digits);
-      STD_string A_expected_str     =ftos(A_expected,digits);
-      STD_string lambda_str         =ftos(expf.lambda.val,digits);
-      STD_string lambda_expected_str=ftos(lambda_expected,digits);
 
-      if(A_str     !=A_expected_str)      {ODINLOG(odinlog,errorLog) << fitterlabel << "(ExponentialFunction) failed: A="      << A_str      << ", but expected A="      << A_expected_str      << STD_endl; return false;}
-      if(lambda_str!=lambda_expected_str) {ODINLOG(odinlog,errorLog) << fitterlabel << "(ExponentialFunction) failed: lambda=" << lambda_str << ", but expected lambda=" << lambda_expected_str << STD_endl; return false;}
+      float tolerance=1e-4;
+      if( (fabs(expf.A.val-     A_expected)     /A_expected)     >tolerance ) {ODINLOG(odinlog,errorLog) << fitterlabel << "(ExponentialFunction) failed: A="      << expf.A.val      << ", but expected A="      << A_expected      << STD_endl; return false;}
+      if( (fabs(expf.lambda.val-lambda_expected)/lambda_expected)>tolerance ) {ODINLOG(odinlog,errorLog) << fitterlabel << "(ExponentialFunction) failed: lambda=" << expf.lambda.val << ", but expected lambda=" << lambda_expected << STD_endl; return false;}
+
+      // test error only if provided, i.e. if err is non-zero
+      if( expf.A.err!=0.0      && (fabs(expf.A.err-     A_err_expected)     /A_err_expected)     >tolerance ) {ODINLOG(odinlog,errorLog) << fitterlabel << "(ExponentialFunction) failed: A_err="      << expf.A.err      << ", but expected A_err="      << A_err_expected      << STD_endl; return false;}
+      if( expf.lambda.err!=0.0 && (fabs(expf.lambda.err-lambda_err_expected)/lambda_err_expected)>tolerance ) {ODINLOG(odinlog,errorLog) << fitterlabel << "(ExponentialFunction) failed: lambda_err=" << expf.lambda.err << ", but expected lambda_err=" << lambda_err_expected << STD_endl; return false;}
+
+//      ODINLOG(odinlog,normalDebug) << fitterlabel << ": A.err/lambda.err=" << expf.A.err << "/" << expf.lambda.err << STD_endl;
 
     } // end iteration over fittermap
 
@@ -977,7 +1007,7 @@ class FunctionFitTest : public UnitTest {
     Data<float,2> testarray(testsize,testsize);
     Data<float,2> testrelia(testsize,testsize);
     TinyVector<int,2> index;
-    for(int i=0; i<testarray.numElements(); i++) {
+    for(unsigned int i=0; i<testarray.numElements(); i++) {
       index=testarray.create_index(i);
       float radius=norm((index(0)-testsize/2),(index(1)-testsize/2));
       radius/=(0.5*float(testsize));
