@@ -48,6 +48,14 @@ struct fitpar {
   * The error interval of the final result.
   */
   float err;
+
+/**
+  * prints fp to the stream s
+  */
+  friend STD_ostream& operator << (STD_ostream& s, const fitpar& fp) {
+    return s << fp.val << " +/- " << fp.err;
+  }
+
 };
 
 
