@@ -21,7 +21,7 @@
 #include <odindata/data.h>
 #include <odindata/utils.h>
 
-#include <odinpara/jdxfilter.h>
+#include <odinpara/ldrfilter.h>
 
 /**
   * @addtogroup odindata
@@ -69,7 +69,7 @@ class Gridding {
   */
   Array<float,N_rank> init(const TinyVector<int,N_rank>& dst_shape, const TinyVector<float,N_rank>& dst_extent,
            const STD_vector<GriddingPoint<N_rank> >& src_coords,
-           const JDXfilter& kernel, float kernel_diameter);
+           const LDRfilter& kernel, float kernel_diameter);
 
 /**
   * Put input array 'src' on the grid by stepping linearly through the inidices.
@@ -95,7 +95,7 @@ class Gridding {
 template <typename T, int N_rank>
 Array<float,N_rank> Gridding<T,N_rank>::init(const TinyVector<int,N_rank>& dst_shape, const TinyVector<float,N_rank>& dst_extent,
            const STD_vector<GriddingPoint<N_rank> >& src_coords,
-           const JDXfilter& kernel, float kernel_diameter) {
+           const LDRfilter& kernel, float kernel_diameter) {
  Log<OdinData> odinlog("Gridding","init");
 
   shape=dst_shape;
@@ -271,7 +271,7 @@ CoordTransformation<T,N_rank,OnPixelRot>::CoordTransformation(const TinyVector<i
   ODINLOG(odinlog,normalDebug) << "source done" << STD_endl;
 
 
-  JDXfilter gridkernel;
+  LDRfilter gridkernel;
   gridkernel.set_function("Gauss");
   gridder.init(shape, shape, src_coords, gridkernel, kernel_size);
 }
