@@ -4,7 +4,7 @@
 
 
 
-Image::Image(const STD_string& label) : JcampDxBlock(label) {
+Image::Image(const STD_string& label) : LDRblock(label) {
   magnitude.set_label("magnitude");
   magnitude.set_filemode(compressed);
 
@@ -13,7 +13,7 @@ Image::Image(const STD_string& label) : JcampDxBlock(label) {
 
 
 Image& Image::operator = (const Image& i) {
-  JcampDxBlock::operator = (i);
+  LDRblock::operator = (i);
   geo=i.geo;
   magnitude=i.magnitude;
   append_all_members();
@@ -57,15 +57,15 @@ Image& Image::transpose_inplane(bool reverse_read, bool reverse_phase) {
 
 
 void  Image::append_all_members() {
-  JcampDxBlock::clear();
-  JcampDxBlock::merge(geo);
+  LDRblock::clear();
+  LDRblock::merge(geo);
   append_member(magnitude);
 }
 
 
 /////////////////////////////////////////////////////////////////
 
-ImageSet::ImageSet(const STD_string& label) : JcampDxBlock(label) {
+ImageSet::ImageSet(const STD_string& label) : LDRblock(label) {
   Content.set_label("Content");
 
   append_all_members();
@@ -174,7 +174,7 @@ ImageSet::ImageSet(const Sample& smp) {
 
 
 ImageSet& ImageSet::operator = (const ImageSet& is) {
-  JcampDxBlock::operator = (is);
+  LDRblock::operator = (is);
   Content=is.Content;
   images=is.images;
   append_all_members();
@@ -184,12 +184,12 @@ ImageSet& ImageSet::operator = (const ImageSet& is) {
 ImageSet& ImageSet::append_image(const Image& img) {
   Log<OdinData> odinlog(this,"append_image");
   bool rename=false;
-  if(img.get_label()=="" || JcampDxBlock::parameter_exists(img.get_label())) rename=true;
+  if(img.get_label()=="" || LDRblock::parameter_exists(img.get_label())) rename=true;
   images.push_back(img);
   STD_list<Image>::iterator it=images.end();
   --it;
   if(rename) it->set_label("Image"+itos(images.size()-1));
-  JcampDxBlock::append(*it);
+  LDRblock::append(*it);
 
   unsigned int nimages=images.size();
   ODINLOG(odinlog,normalDebug) << "nimages=" << nimages << STD_endl;
@@ -223,13 +223,13 @@ Image& ImageSet::get_image(unsigned int index) {
 }
 
 
-int ImageSet::load(const STD_string& filename) {
+int ImageSet::load(const STD_string& filename, const LDRserBase& serializer) {
   Log<OdinData> odinlog(this,"load");
 
   clear_images();
 
   // check whether we have a whole set of images and determine the total num of images first
-  int noiresult=Content.load(filename);
+  int noiresult=Content.load(filename,serializer);
   svector contcopy=Content; // create copy because append_image will modify Content
   unsigned int nimages=contcopy.size();
   ODINLOG(odinlog,normalDebug) << "noiresult/nimages/Content=" << noiresult << "/" << nimages << "/" << contcopy.printbody() << STD_endl;
@@ -244,11 +244,11 @@ int ImageSet::load(const STD_string& filename) {
       ODINLOG(odinlog,normalDebug) << "Appended empty image for " << STD_string(contcopy[i]) << STD_endl;
     }
     ODINLOG(odinlog,normalDebug) << "Loading all images" << STD_endl;
-    result=JcampDxBlock::load(filename);
+    result=LDRblock::load(filename,serializer);
   } else {
     // try single image
     Image img;
-    result=img.load(filename);
+    result=img.load(filename,serializer);
     if(result>0) {
       clear_images();
       append_image(img);
@@ -259,6 +259,6 @@ int ImageSet::load(const STD_string& filename) {
 
 
 void ImageSet::append_all_members() {
-  JcampDxBlock::clear();
+  LDRblock::clear();
   append_member(Content);
 }
