@@ -2,7 +2,7 @@
                           image.h  -  description
                              -------------------
     begin                : Fr Feb 25 2005
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -20,7 +20,7 @@
 
 
 #include <odinpara/protocol.h>
-//#include <odindata/data.h>
+
 
 class Sample; // forward declaration
 
@@ -34,7 +34,7 @@ class Sample; // forward declaration
 /**
   * Class to hold reconstructed images of one Geometry
   */
-class Image : public JcampDxBlock {
+class Image : public LDRblock {
 
  public:
 
@@ -97,7 +97,7 @@ class Image : public JcampDxBlock {
   void append_all_members();
 
   Geometry geo;
-  JDXfloatArr magnitude;
+  LDRfloatArr magnitude;
 
 };
 
@@ -106,7 +106,7 @@ class Image : public JcampDxBlock {
 /**
   * Class to hold a whole list of Image's
   */
-class ImageSet : public JcampDxBlock {
+class ImageSet : public LDRblock {
 
  public:
 
@@ -154,15 +154,15 @@ class ImageSet : public JcampDxBlock {
   Image& get_image(unsigned int index=0);
 
 
-  // overloading virtual functions of JcampDxBlock
-  int load(const STD_string& filename);
+  // overloading virtual functions of LDRblock
+  int load(const STD_string& filename, const LDRserBase& serializer=LDRserJDX());
 
 
  private:
 
   void append_all_members();
 
-  JDXstringArr Content;
+  LDRstringArr Content;
   STD_list<Image> images;
 
   Image dummy;
