@@ -37,7 +37,7 @@ class StatisticsTest : public UnitTest {
 
     Data<float,2> testarray(testsize,testsize);
     TinyVector<int, 2> index;
-    for(int i=0; i<testarray.numElements(); i++) {
+    for(unsigned int i=0; i<testarray.numElements(); i++) {
       index=testarray.create_index(i);
       testarray(index)=float(index(0))+float(index(1));
     }
