@@ -2,7 +2,7 @@
                           statistics.h  -  description
                              -------------------
     begin                : Fri Apr 6 2001
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -191,7 +191,7 @@ T weightmean(const Array<T,N_rank>& ensemble, const Array<float,N_rank>& weight)
 
   float weightsum=0.0;
   TinyVector<int,N_rank> index;
-  for(int i=0; i<ensemble_copy.numElements(); i++) {
+  for(unsigned int i=0; i<ensemble_copy.numElements(); i++) {
     index=ensemble_copy.create_index(i);
     float w=fabs(weight(index));
     result+=w*ensemble_copy(index);
