@@ -2,7 +2,7 @@
                           step.h  -  description
                              -------------------
     begin                : Sat Dec 30 2006
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -84,7 +84,7 @@ class Step {
 /**
   * Append arguments of the functor to parblock.
   */
-  void append_opts(JcampDxBlock& parblock);
+  void append_opts(LDRblock& parblock);
 
 
  protected:
@@ -93,14 +93,14 @@ class Step {
 /**
   * Append step argument, to be used in init() of each step.
   */
-  void append_arg(JcampDxClass& arg, const STD_string& arglabel);
+  void append_arg(LDRbase& arg, const STD_string& arglabel);
 
 
   const char* c_label() const {if(!label_cache.size()) label_cache=label(); return label_cache.c_str();} // For Debug
 
  private:
 
-  JcampDxBlock args;
+  LDRblock args;
   mutable STD_string label_cache;
 };
 
@@ -119,7 +119,7 @@ class StepFactory {
 /**
   * Set up factory (creates template objects). Appends parameters of all steps to 'parblock'.
   */
-  StepFactory(JcampDxBlock* parblock=0);
+  StepFactory(LDRblock* parblock=0);
 
   ~StepFactory();
 
