@@ -137,7 +137,7 @@ Geometry& Geometry::reset() {
 }
 
 
-Geometry::Geometry(const STD_string& label) : JcampDxBlock(label) {
+Geometry::Geometry(const STD_string& label) : LDRblock(label) {
   Log<Para> odinlog(this,"Geometry(const STD_string&)");
 
   Mode.add_item("SlicePack",slicepack);
@@ -192,11 +192,11 @@ Geometry::Geometry(const Geometry& ia) {
 
 Geometry& Geometry::operator = (const Geometry& ia) {
   Log<Para> odinlog(this,"Geometry::operator =");
-  JcampDxBlock::operator = (ia);
+  LDRblock::operator = (ia);
 
   append_all_members();
 
-  // copy only visible members of JcampDxBlock
+  // copy only visible members of LDRblock
   copy_ldr_vals(ia);
   update();
   return *this;
@@ -206,7 +206,7 @@ Geometry& Geometry::operator = (const Geometry& ia) {
 Geometry& Geometry::set_Mode(geometryMode mode) {
   Log<Para> odinlog(this,"set_Mode");
   Mode.set_actual(mode);
-  ODINLOG(odinlog,normalDebug) << "Mode/mode=" << Mode.JDXenum::operator STD_string() << "/" << mode << STD_endl;
+  ODINLOG(odinlog,normalDebug) << "Mode/mode=" << Mode.LDRenum::operator STD_string() << "/" << mode << STD_endl;
   update();
   return *this;
 }
@@ -244,10 +244,10 @@ Geometry& Geometry::update() {
 
 /*
 int Geometry::load(const STD_string &filename) {
-  int stat=JcampDxBlock::load(filename); // read once to set correct mode
+  int stat=LDRblock::load(filename); // read once to set correct mode
   if(stat<=0) return -1;
   update(); // set new mode
-  return JcampDxBlock::load(filename);
+  return LDRblock::load(filename);
 }
 */
 
@@ -654,7 +654,7 @@ Geometry& Geometry::transpose_inplane(bool reverse_read, bool reverse_phase) {
 void  Geometry::append_all_members() {
   Log<Para> odinlog(this,"append_all_members");
 
-  JcampDxBlock::clear();
+  LDRblock::clear();
 
   append_member(Mode,"Mode");
   append_member(Reset,"Reset");
