@@ -2,7 +2,7 @@
                           odinpara.h  -  description
                              -------------------
     begin                : Tue Jun 28 2005
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -20,6 +20,7 @@
 
 
 
+#include <tjutils/tjtools.h>
 
 /**
   * @addtogroup odinpara
@@ -36,6 +37,7 @@
   */
 enum direction                      { readDirection=0, phaseDirection,  sliceDirection, n_directions};
 static const char* directionLabel[]={"readDirection", "phaseDirection","sliceDirection"};
+AVOID_CC_WARNING(directionLabel)
 
 /**
   * Enum for the direction of spatial axes in the laboratory system of reference:
