@@ -2,7 +2,7 @@
 
 #include <tjutils/tjtest.h>
 
-Protocol::Protocol(const STD_string& label) : JcampDxBlock(label),
+Protocol::Protocol(const STD_string& label) : LDRblock(label),
   system(label+"_system"),
   geometry(label+"_geometry"),
   seqpars(label+"_seqpars"),
@@ -13,7 +13,7 @@ Protocol::Protocol(const STD_string& label) : JcampDxBlock(label),
 
 
 Protocol& Protocol::operator = (const Protocol& p) {
-  JcampDxBlock::operator = (p);
+  LDRblock::operator = (p);
   system=p.system;
   geometry=p.geometry;
   seqpars=p.seqpars;
@@ -28,6 +28,7 @@ bool Protocol::operator < (const Protocol& rhs) const {
   exclude.push_back("AcquisitionStart");
   exclude.push_back("offsetSlice");
   exclude.push_back("Datatype");
+  exclude.push_back("ReceiveCoilName"); // can be different in composed data
   
   // account for different TRs in gated mode
   if(seqpars.get_PhysioTrigger() || rhs.seqpars.get_PhysioTrigger()) {
@@ -37,12 +38,12 @@ bool Protocol::operator < (const Protocol& rhs) const {
   }
 
   double accuracy=0.01; // This will make geometries equal which are approximately the same
-  return JcampDxBlock::compare(rhs,&exclude,accuracy);
+  return LDRblock::compare(rhs,&exclude,accuracy);
 }
 
 
 void Protocol::append_all_members() {
-  JcampDxBlock::clear();
+  LDRblock::clear();
   merge(study);
   merge(system);
   merge(geometry);
@@ -64,7 +65,7 @@ class ProtocolTest : public UnitTest {
   bool check() const {
     Log<UnitTest> odinlog(this,"check");
 
-    // Testing == operator (of JcampDxBlock)
+    // Testing == operator (of LDRblock)
     Protocol p1;
     Protocol p2;
 
@@ -91,22 +92,23 @@ class ProtocolTest : public UnitTest {
     }
 
     SeqPars sp;
-    if( p1.JcampDxBlock::operator == (sp) ) {
+    if( p1.LDRblock::operator == (sp) ) {
       ODINLOG(odinlog,errorLog) << "Protocol::operator == (SeqPars) failed: p1=" << p1 << "sp=" << sp << STD_endl;
       return false;
     }
 
 
     // Testing copying of custom parameters
-    JDXint testint(7,"testint");
+    LDRint testint(7,"testint");
     p1.methpars.append(testint);
     p2=p1;
-    JcampDxClass* pjdx=p2.get_parameter("testint");
-    if( !pjdx ) {
+    LDRbase* pldr=p2.get_parameter("testint");
+    if( !pldr ) {
       ODINLOG(odinlog,errorLog) << "Protocol::operator =  methpars.testint not found" << STD_endl;
       return false;
     }
-    int* intdummy=pjdx->cast(intdummy);
+    int* intdummy=0; // avoid compiler warning
+    intdummy=pldr->cast(intdummy);
     if( !intdummy ) {
       ODINLOG(odinlog,errorLog) << "Protocol::operator =  methpars.testint cannot be casted" << STD_endl;
       return false;
