@@ -2,7 +2,7 @@
                           protocol.h  -  description
                              -------------------
     begin                : Tue Jul 5 2005
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -30,7 +30,7 @@
   *
   * Class to hold the whole MR Protocol, that is system, geometry and seqpars
   */
-class Protocol : public JcampDxBlock {
+class Protocol : public LDRblock {
 
 
  public:
@@ -85,7 +85,7 @@ class Protocol : public JcampDxBlock {
 /**
   * method-specific parameters
   */
-  JcampDxBlock methpars;
+  LDRblock methpars;
 
 /**
   * study information
