@@ -1,6 +1,6 @@
 #include "sample.h"
 
-Sample::Sample(const STD_string& label, bool uniformFOV, bool uniformT1T2) : JcampDxBlock(label) {
+Sample::Sample(const STD_string& label, bool uniformFOV, bool uniformT1T2) : LDRblock(label) {
 
   uniFOV=uniformFOV;
   uniT1T2=uniformT1T2;
@@ -43,7 +43,7 @@ Sample::Sample(const Sample& ss) {
 
 
 Sample& Sample::operator = (const Sample& ss) {
-  JcampDxBlock::operator = (ss);
+  LDRblock::operator = (ss);
 
   FOVall=ss.FOVall;
   FOV=ss.FOV;
@@ -262,9 +262,9 @@ Sample& Sample::update() {
 }
 
 
-int Sample::load(const STD_string& filename) {
+int Sample::load(const STD_string& filename, const LDRserBase& serializer) {
   Log<Para> odinlog(this,"load");
-  int errval=JcampDxBlock::load(filename);
+  int errval=LDRblock::load(filename,serializer);
 
   ndim nn=spinDensity.get_extent();
 
