@@ -1,6 +1,6 @@
 #include "seqpars.h"
 
-SeqPars::SeqPars(const STD_string& label) : JcampDxBlock(label) {
+SeqPars::SeqPars(const STD_string& label) : LDRblock(label) {
 
   ExpDuration.set_parmode(noedit);
   ExpDuration.set_description("The overall duration of the sequence");
@@ -148,10 +148,10 @@ SeqPars& SeqPars::set_PhysioTrigger(bool flag, parameterMode parmode) {
 
 
 SeqPars& SeqPars::operator = (const SeqPars& pars2) {
-  JcampDxBlock::operator = (pars2);
+  LDRblock::operator = (pars2);
   append_all_members();
 
-  // copy only visible members of JcampDxBlock
+  // copy only visible members of LDRblock
   copy_ldr_vals(pars2);
 
   return *this;
@@ -160,7 +160,7 @@ SeqPars& SeqPars::operator = (const SeqPars& pars2) {
 
 
 void SeqPars::append_all_members() {
-  JcampDxBlock::clear();
+  LDRblock::clear();
   append_member(ExpDuration,"ExpDuration");
   append_member(Sequence,"Sequence");
   append_member(AcquisitionStart,"AcquisitionStart");
