@@ -2,7 +2,7 @@
                           study.h  -  description
                              -------------------
     begin                : Mon Mar 3 2003
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -18,9 +18,9 @@
 #ifndef STUDY_H
 #define STUDY_H
 
-#include <odinpara/jdxblock.h>
-#include <odinpara/jdxtypes.h>
-#include <odinpara/jdxnumbers.h>
+#include <odinpara/ldrblock.h>
+#include <odinpara/ldrtypes.h>
+#include <odinpara/ldrnumbers.h>
 
 
 #define ODIN_DATE_LENGTH 8
@@ -36,7 +36,7 @@
   *
   * This class is used to hold study information
   */
-class Study : public JcampDxBlock {
+class Study : public LDRblock {
 
  public:
 
@@ -76,13 +76,14 @@ class Study : public JcampDxBlock {
   * -birth_date: Patients date of birth in DICOM format, i.e yyyymmdd
   * -sex:        Patients sex (M,F,O)
   * -weight:     Patients weight [kg]
+  * -size:       Patients size/height [mm]
   */
-  Study& set_Patient(const STD_string& id, const STD_string& full_name, const STD_string& birth_date, char sex, float weight);
+  Study& set_Patient(const STD_string& id, const STD_string& full_name, const STD_string& birth_date, char sex, float weight, float size);
 
 /**
   * Returns the patient information in the reference parameters, see set_Patient() for their description
   */
-  void get_Patient(STD_string& id, STD_string& full_name, STD_string& birth_date, char& sex, float& weight) const;
+  void get_Patient(STD_string& id, STD_string& full_name, STD_string& birth_date, char& sex, float& weight, float& size) const;
 
 
 /**
@@ -124,20 +125,21 @@ class Study : public JcampDxBlock {
   static void format_date(STD_string& result, const STD_string& date);
   static void format_time(STD_string& result, const STD_string& time);
 
-  JDXstring ScanDate;
-  JDXstring ScanTime;
+  LDRstring ScanDate;
+  LDRstring ScanTime;
 
-  JDXstring PatientId;
-  JDXstring PatientName;
-  JDXstring PatientBirthDate;
-  JDXenum   PatientSex;
-  JDXfloat  PatientWeight;
+  LDRstring PatientId;
+  LDRstring PatientName;
+  LDRstring PatientBirthDate;
+  LDRenum   PatientSex;
+  LDRfloat  PatientWeight;
+  LDRfloat  PatientSize;
 
-  JDXstring Description;
-  JDXstring ScientistName;
+  LDRstring Description;
+  LDRstring ScientistName;
 
-  JDXstring SeriesDescription;
-  JDXint    SeriesNumber;
+  LDRstring SeriesDescription;
+  LDRint    SeriesNumber;
 
 };
 
