@@ -31,7 +31,7 @@ bool RecoAdcGridPrep::process(RecoData& rd, RecoController& controller) {
 
       int npts=indata.size();
       ODINLOG(odinlog,normalDebug) << "npts=" << npts << STD_endl;
-      if(readoutShape.size()!=npts) {
+      if(int(readoutShape.size())!=npts) {
         trajmutex.unlock();
         ODINLOG(odinlog,errorLog) << "Size mismatch: " << readoutShape.size() << "!=" << npts << STD_endl;
         return false;
@@ -70,8 +70,6 @@ bool RecoAdcGridPrep::process(RecoData& rd, RecoController& controller) {
 bool RecoAdcWeight::process(RecoData& rd, RecoController& controller) {
   Log<Reco> odinlog(c_label(),"process");
 
-  Range all=Range::all();
-
   const ComplexData<1>* weightVec=rd.coord().weightVec;
   if(weightVec) {
     MutexLock lock(weightMutex); // protect global weightVec
@@ -105,7 +103,7 @@ bool RecoAdcBaseline::process(RecoData& rd, RecoController& controller) {
   // Calculate mean complex offset of samples with small magnitude
   int nsamples_bline=0;
   STD_complex sigsum(0.0);
-  for(int isample=0; isample<adc.size(); isample++) {
+  for(int isample=0; isample<int(adc.size()); isample++) {
     STD_complex sigval=adc(isample);
     if(cabs(sigval)<0.05*maxsig) {
       sigsum+=sigval;
