@@ -2,7 +2,7 @@
                           blackboard.h  -  description
                              -------------------
     begin                : Mon Jan 24 2007
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -105,7 +105,7 @@ class RecoPost : public RecoStep {
   RecoStep* allocate() const {return new RecoPost;}
   void init();
 
-  JDXstring postlabel;
+  LDRstring postlabel;
 
 };
 
