@@ -51,7 +51,7 @@ bool RecoBladeGrid::process(RecoData& rd, RecoController& controller) {
 
   ComplexData<4> infixed(inshape(0),indexvec3d.size(),inshape(2),inshape(3));
 
-  for(int i = 0; i < indexvec3d.size(); i++) {
+  for(unsigned int i=0; i<indexvec3d.size(); i++) {
 
     int iphase3d = indexvec3d[i];
     infixed(all,i,all,all) = data(all,iphase3d,all,all);
@@ -99,7 +99,7 @@ bool RecoCycleRot::process(RecoData& rd, RecoController& controller) {
 
 
   // feed each rotated dataset into rest of pipeline
-  for(int i=0; i<angles.size(); i++) {
+  for(unsigned int i=0; i<angles.size(); i++) {
 
     RecoData rdcopy(rd);
 
@@ -224,7 +224,7 @@ bool RecoBladeCorr::process(RecoData& rd, RecoController& controller) {
     RecoData rddeapo;
     if(!controller.inquire_data(deapo_postlabel, rddeapo)) return false;
     const ComplexData<1>& deapoline=rddeapo.data(Rank<1>());
-    if(deapoline.size()!=inshape3d(2)) {
+    if(int(deapoline.size())!=inshape3d(2)) {
       ODINLOG(odinlog,errorLog) << "Size mistmatch" << STD_endl;
       return false;
     }
@@ -344,9 +344,13 @@ bool RecoBladeComb::process(RecoData& rd, RecoController& controller) {
   TinyVector<int,4> inshape=indata.shape();
   TinyVector<int,3> inshape3d(inshape(1), inshape(2), inshape(3));
 
-  int nblades=inshape(0);
+  unsigned int nblades=inshape(0);
   dvector angles=controller.dim_values(cycle);
   ODINLOG(odinlog,normalDebug) << "angles=" << angles.printbody() << STD_endl;
+  if(nblades!=angles.size()) {
+    ODINLOG(odinlog,errorLog) << "nblades(" << nblades << ") != nangles(" << angles.size() << ")" << STD_endl;
+    return false;
+  }
 
   TinyVector<float,3> fov; fov=1;
 //  fov(0)=controller.protocol().geometry.get_FOV(sliceDirection); // No regridding in line3d direction
@@ -367,7 +371,7 @@ bool RecoBladeComb::process(RecoData& rd, RecoController& controller) {
     }
 
     // Filter for k-space center
-    JDXfilter kernel_center;
+    LDRfilter kernel_center;
     kernel_center.set_funcpars("Triangle");
 
     // Prepare Input Data
@@ -376,7 +380,7 @@ bool RecoBladeComb::process(RecoData& rd, RecoController& controller) {
 
     ComplexData<4> infixed(inshape(0),indexvec3d.size(),inshape(2),inshape(3));
 
-    for(int i = 0; i < indexvec3d.size(); i++) {
+    for(unsigned int i=0; i<indexvec3d.size(); i++) {
 
       int iphase3d = indexvec3d[i];
       infixed(all,i,all,all) = indata(all,iphase3d,all,all);
@@ -402,14 +406,14 @@ bool RecoBladeComb::process(RecoData& rd, RecoController& controller) {
       // Merge all blades
       Data<float, 2> bladesmean(gridshape(2),gridshape(3));
       bladesmean = 0.0;
-      for (int iblade = 0; iblade < nblades; iblade++) {
+      for (unsigned int iblade = 0; iblade < nblades; iblade++) {
         bladesmean += bladesgrid(iblade,iphase3d,all,all);
       }
       bladesmean /= nblades;
       //bladesmean.autowrite("grid-blades-mean.nii");
 
       // Calculate correlation coefficient for all blades
-      for (int iblade = 0; iblade < nblades; iblade++) {
+      for (unsigned int iblade = 0; iblade < nblades; iblade++) {
         correlationResult cr = correlation(bladesmean,bladesgrid(iblade,iphase3d,all,all));
         corrweights(iblade) += cr.r;
       }
@@ -511,7 +515,7 @@ bool RecoBladeComb::process(RecoData& rd, RecoController& controller) {
   ivector indexvec3d=measlines.get_indices(rd.coord()); // Use only planes actually measured
 
   // feed each 3d-phase encoded k-space plane separately into rest of pipeline
-  for(int i=0; i<indexvec3d.size(); i++) {
+  for(unsigned int i=0; i<indexvec3d.size(); i++) {
 
     int iphase3d=indexvec3d[i];
 
