@@ -35,14 +35,14 @@ bool RecoChannelSum::process(RecoData& rd, RecoController& controller) {
 
     outdata=STD_complex(0.0);
 
-    for(int i=0; i<outdata.size(); i++) {
+    for(unsigned int i=0; i<outdata.size(); i++) {
       TinyVector<int,3> index=outdata.create_index(i);
 
       float valsum=0.0;
       float relsum=0.0;
-      for(int i=0; i<nchan; i++) {
-        float val=indata(i,index(0),index(1),index(2)).real();
-        float rel=indata(i,index(0),index(1),index(2)).imag();
+      for(int ichan=0; ichan<nchan; ichan++) {
+        float val=indata(ichan,index(0),index(1),index(2)).real();
+        float rel=indata(ichan,index(0),index(1),index(2)).imag();
         valsum+=val*rel;
         relsum+=rel;
       }
