@@ -8,7 +8,7 @@
 
 
 
-RecoController::RecoController(JcampDxBlock& parblock) : input(0), pipeline(0), factory(0), pmeter(display) {
+RecoController::RecoController(LDRblock& parblock) : input(0), pipeline(0), factory(0), pmeter(display) {
 
   jobs=numof_cores();
   jobs.set_cmdline_option("j").set_description("Number of concurrent jobs(threads) in reco");
@@ -55,6 +55,10 @@ RecoController::RecoController(JcampDxBlock& parblock) : input(0), pipeline(0),
   dumpGrappaTemplate.set_cmdline_option("gt").set_description("Store GRAPPA template images");
   parblock.append(dumpGrappaTemplate);
 
+  disablePhaseCorr=false;
+  disablePhaseCorr.set_cmdline_option("dt").set_description("Disable template-based phase correction");
+  parblock.append(disablePhaseCorr);
+
   disableHomodyne=false;
   disableHomodyne.set_cmdline_option("dh").set_description("Disable homodyne reconstruction");
   parblock.append(disableHomodyne);
@@ -336,8 +340,9 @@ RecoStep* RecoController::create_pipeline(const STD_string& rec, const RecoCoord
     STD_string functorstr=shrink(toks[itok]);
     STD_string args=extract(functorstr, "(", ")", true);
     functorstr=rmblock(functorstr, "(", ")", true, true, false, true);
-    ODINLOG(odinlog,normalDebug) << "toks/functorstr/args[" << itok << "]=>" << toks[itok] << "/" << functorstr << "/" << args << "<" << STD_endl;
+    ODINLOG(odinlog,normalDebug) << "toks/args[" << itok << "]=>" << toks[itok] << "/" << args << "<" << STD_endl;
 
+    ODINLOG(odinlog,normalDebug) << "functorstr=>" << functorstr << "<" << STD_endl;
     RecoStep* step=factory->create(functorstr);
     if(!step) {
       ODINLOG(odinlog,errorLog) << "Could not create functor with label >" << functorstr << "<" << STD_endl;
@@ -404,11 +409,12 @@ class TimeOutThread : public Thread {
 //////////////////////////////////////////////////////////////////////////////////////
 
 template<recoDim Dim, recoDim OrthoDim>
-bool RecoController::get_kspace_sampling_pattern(const RecoCoord& mask, unsigned int& reduction_factor, bool& partial_fourier) const {
+bool RecoController::get_kspace_sampling_pattern(const RecoCoord& mask, unsigned int& reduction_factor, bool& partial_fourier, bool& half_fourier) const {
   Log<Reco> odinlog("RecoController","get_kspace_sampling_pattern");
 
   reduction_factor=1;
   partial_fourier=false;
+  half_fourier=false;
 
   if(numof_cache[Dim]<2) return true;
 
@@ -429,9 +435,24 @@ bool RecoController::get_kspace_sampling_pattern(const RecoCoord& mask, unsigned
       reduction_factor=STD_max(int(reduction_factor),diff);
     }
 
-    if(indexvec.size() && indexvec[0]>=int(reduction_factor)) partial_fourier=true;
+    unsigned int nindices=indexvec.size();
+    if(nindices) {
+     int startindex=indexvec[0];
+     int maxindex=indexvec[nindices-1];
+
+     if(startindex>=int(reduction_factor)) partial_fourier=true;
+
+     float center=0.5*float(maxindex);
+     ODINLOG(odinlog,normalDebug) << "startindex/maxindex/center[" << recoDimLabel[Dim] << "]=" << startindex << "/" << maxindex << "/" << center << STD_endl;
+
+     if(fabs(float(startindex)-center)<=1.0) half_fourier=true;
+    }
   }
 
+  if(reduction_factor<1) reduction_factor=1;
+
+  ODINLOG(odinlog,normalDebug) << "reduction_factor/partial_fourier/half_fourier[" << recoDimLabel[Dim] << "]=" << reduction_factor << "/" << partial_fourier << "/" << half_fourier << STD_endl;
+
   return true;
 }
 
@@ -447,13 +468,18 @@ bool RecoController::autorecipe(const RecoCoord& mask, STD_string& result) const
 
   unsigned int reduction_factor=0;
   bool partial_fourier=false;
-  if(!get_kspace_sampling_pattern<line,line3d>(mask,reduction_factor, partial_fourier)) return false;
-  ODINLOG(odinlog,normalDebug) << "reduction_factor/partial_fourier=" << reduction_factor << "/" << partial_fourier << STD_endl;
+  bool half_fourier=false;
+  if(!get_kspace_sampling_pattern<line,line3d>(mask,reduction_factor, partial_fourier, half_fourier)) return false;
 
   unsigned int reduction_factor3d=0;
   bool partial_fourier3d=false;
-  if(!get_kspace_sampling_pattern<line3d,line>(mask,reduction_factor3d, partial_fourier3d)) return false;
-  ODINLOG(odinlog,normalDebug) << "reduction_factor3d/partial_fourier3d=" << reduction_factor3d << "/" << partial_fourier3d << STD_endl;
+  bool half_fourier3d=false;
+  if(!get_kspace_sampling_pattern<line3d,line>(mask,reduction_factor3d, partial_fourier3d, half_fourier3d)) return false;
+
+  if(half_fourier3d) {
+    ODINLOG(odinlog,errorLog) << "Not yet implemented: half Fourier reconstruction in 2nd phase encoding direction" << STD_endl;
+    return false;
+  }
 
 
   unsigned int max_reduction_factor=STD_max(reduction_factor,reduction_factor3d);
@@ -507,7 +533,7 @@ bool RecoController::autorecipe(const RecoCoord& mask, STD_string& result) const
 
   STD_string phasecorrstr;
   if(has_templcorr_cache[phasecorr_template]) {
-    phasecorrstr="phasecorr | ";
+    if(!disablePhaseCorr) phasecorrstr="phasecorr | ";
     corrstr+="templtype=P { "+averagestr+adcprep+"echocoll | phasemap}";
   }
 
@@ -518,28 +544,32 @@ bool RecoController::autorecipe(const RecoCoord& mask, STD_string& result) const
   STD_string mfreqend;
   STD_string chansumopt;
   bool ext_fieldmap=fieldmapFile!="";
-  if(!disableMultiFreq && (has_templcorr_cache[fieldmap_template] || ext_fieldmap) ) {
-    if(!conjPhaseFT && !dumpKspace) {
-      mfreqbegin="multifreq | ";
-      mfreqend="freqcoll | freqcomb | ";
-    }
+  if(has_templcorr_cache[fieldmap_template] || ext_fieldmap) {
+    if(disableMultiFreq) {
+      corrstr+="templtype=F { }"; // throw away field map data
+    } else {
 
-    if(!ext_fieldmap) {
-      if(corrstr!="") corrstr+="; ";
+      if(!conjPhaseFT && !dumpKspace) {
+        mfreqbegin="multifreq | ";
+        mfreqend="freqcoll | freqcomb | ";
+      }
 
-      STD_string fmap_offsetstr="offset | ";
-      if(has_blade && mfreqend!="") fmap_offsetstr=""; // disable offset for multi-frequency reco of blades
+      if(!ext_fieldmap) {
+        if(corrstr!="") corrstr+="; ";
+
+        STD_string fmap_offsetstr="offset | ";
+        if(has_blade && mfreqend!="") fmap_offsetstr=""; // disable offset for multi-frequency reco of blades
 
 
-      //STD_string cyclerotstr;
-      //if(has_blade) cyclerotstr="cyclerot | ";
-      //corrstr+="templtype=F { adc_reflect | kspace | offset | filter(Hann) | fft | tecoll | fieldmap | "+chanstr+"interpolate | "+cyclerotstr+"post(fieldmap) | "+oversamplingstr+"slicecoll | image | store(fieldmap)}";
-      corrstr+="templtype=F { adc_reflect | kspace |"+fmap_offsetstr+"filter(Hann) | fft | tecoll | fieldmap | "+chanstr+oversamplingstr+" post(fieldmap) | "+"slicecoll | image | store(fieldmap)}";
+        //STD_string cyclerotstr;
+        //if(has_blade) cyclerotstr="cyclerot | ";
+        //corrstr+="templtype=F { adc_reflect | kspace | offset | filter(Hann) | fft | tecoll | fieldmap | "+chanstr+"interpolate | "+cyclerotstr+"post(fieldmap) | "+oversamplingstr+"slicecoll | image | store(fieldmap)}";
+        corrstr+="templtype=F { adc_reflect | kspace |"+fmap_offsetstr+"filter(Hann) | fft | tecoll | fieldmap | "+chanstr+oversamplingstr+" post(fieldmap) | "+"slicecoll | image | store(fieldmap)}";
+      }
     }
   }
 
 
-
   if(has_navigator_cache[epi_navigator]) {
     phasecorrstr="epinavcorr | ";
     if(navstr!="") navstr+="; ";
@@ -580,13 +610,10 @@ bool RecoController::autorecipe(const RecoCoord& mask, STD_string& result) const
 
   STD_string fftstr="fft | ";
   if(!has_traj && !disableHomodyne) {
-    unsigned int homodyne_dims=0;
-    if(has_relcenter_cache)            {fftstr="homodyneread | "; homodyne_dims++;}
-    if (partial_fourier && !has_blade) {fftstr="homodyne | ";     homodyne_dims++;}
-    if(partial_fourier3d)              {fftstr="homodyne3d | ";   homodyne_dims++;}
-    if(homodyne_dims>1) { 
-      ODINLOG(odinlog,errorLog) << "Not yet implemented: partial Fourier reconstruction in more than one direction" << STD_endl;
-      return false;
+    if(has_relcenter_cache || partial_fourier3d) {fftstr="homodyne | ";}
+    if(!has_blade) {
+      if(half_fourier)         {fftstr="halffour | fft | ";}
+      else if(partial_fourier) {fftstr="homodyne | ";}
     }
   }
 
@@ -755,7 +782,7 @@ bool RecoController::create_selection_map(const STD_string& selstr, STD_map<reco
 
 //////////////////////////////////////////////////////////////////////////////////////
 
-bool RecoController::init(RecoReaderInterface* reader, JcampDxBlock& opts, int argc, char* argv[]) {
+bool RecoController::init(RecoReaderInterface* reader, LDRblock& opts, int argc, char* argv[]) {
   Log<Reco> odinlog("RecoController","init");
 
   input=reader;
@@ -848,7 +875,7 @@ bool RecoController::init(RecoReaderInterface* reader, JcampDxBlock& opts, int a
 
 
   // get recipe
-  if(recipeFile!="") load(recipe,recipeFile);
+  if(recipeFile!="") ::load(recipe,recipeFile);
   if(recipe=="") {
     STD_string recipe_seq=input->seqrecipe();
     if(recipe_seq!="") {
