@@ -2,7 +2,7 @@
                           controller.h  -  description
                              -------------------
     begin                : Sat Dec 30 2006
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -53,7 +53,7 @@ class RecoController {
 /**
   * Creates uninitialized reconstruction controller.  Appends parameters to 'parblock'.
   */
-  RecoController(JcampDxBlock& parblock);
+  RecoController(LDRblock& parblock);
 
   ~RecoController();
 
@@ -61,7 +61,7 @@ class RecoController {
   * Initializes reconstruction process controller to use reco input 'reader'
   * and option block 'opts'. Returns 'true' only if sucessful.
   */
-  bool init(RecoReaderInterface* reader, JcampDxBlock& opts, int argc, char* argv[]);
+  bool init(RecoReaderInterface* reader, LDRblock& opts, int argc, char* argv[]);
 
 /**
   * Starts reconstruction process using 'firststep' as the start of the
@@ -160,31 +160,32 @@ class RecoController {
 
 
   // Options
-  JDXint jobs;
-  JDXstring recipe;
-  JDXstring recipeFile;
-  JDXstring select;
-  JDXint    timeout;
-  JDXint    maxrecursion;
-  JDXbool   conjPhaseFT;
-  JDXbool   slidingWindow;
-  JDXbool   keyhole;
-  JDXbool   sepChannels;
-  JDXbool   dumpKspace;
-  JDXbool   dumpGrappaTemplate;
-  JDXbool   disableHomodyne;
-  JDXbool   disableMultiFreq;
-  JDXbool   disableDriftCorr;
-  JDXbool   disableSliceTime;
-  JDXbool   disableGrappa;
-  JDXbool   phaseCourse;
-  JDXbool   qcspike;
-  JDXstring preproc3d;
-  JDXstring postproc3d;
-  JDXstring dumpRawPrefix;
-  JDXstring fieldmapFile;
-//  JDXstring driftcorrFile;
-  JDXstring driftcorrSel;
+  LDRint jobs;
+  LDRstring recipe;
+  LDRstring recipeFile;
+  LDRstring select;
+  LDRint    timeout;
+  LDRint    maxrecursion;
+  LDRbool   conjPhaseFT;
+  LDRbool   slidingWindow;
+  LDRbool   keyhole;
+  LDRbool   sepChannels;
+  LDRbool   dumpKspace;
+  LDRbool   dumpGrappaTemplate;
+  LDRbool   disablePhaseCorr;
+  LDRbool   disableHomodyne;
+  LDRbool   disableMultiFreq;
+  LDRbool   disableDriftCorr;
+  LDRbool   disableSliceTime;
+  LDRbool   disableGrappa;
+  LDRbool   phaseCourse;
+  LDRbool   qcspike;
+  LDRstring preproc3d;
+  LDRstring postproc3d;
+  LDRstring dumpRawPrefix;
+  LDRstring fieldmapFile;
+//  LDRstring driftcorrFile;
+  LDRstring driftcorrSel;
 
   bool execute_pipeline();
   bool prepare_pipeline();
@@ -198,7 +199,7 @@ class RecoController {
   static int controlthread;
 
   template<recoDim Dim, recoDim OrthoDim>
-  bool get_kspace_sampling_pattern(const RecoCoord& mask, unsigned int& reduction_factor, bool& partial_fourier) const;
+  bool get_kspace_sampling_pattern(const RecoCoord& mask, unsigned int& reduction_factor, bool& partial_fourier, bool& half_fourier) const;
 
   bool autorecipe(const RecoCoord& mask, STD_string& result) const;
 
