@@ -2,7 +2,7 @@
                           driftcorr.h  -  description
                              -------------------
     begin                : Thu Mar 1 2012
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -38,8 +38,8 @@ class RecoDriftCalc: public RecoStep {
   RecoStep* allocate() const {return new RecoDriftCalc;}
   void init();
 
-  JDXstring driftcalcFile;
-  JDXfloat driftcalcTE;
+  LDRstring driftcalcFile;
+  LDRfloat driftcalcTE;
 
 };
 
