@@ -2,7 +2,7 @@
                           dump.h  -  description
                              -------------------
     begin                : Mon Oct 13 2008
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -31,8 +31,8 @@ class RecoDump : public RecoStep {
   RecoStep* allocate() const {return new RecoDump;}
   void init();
 
-  JDXstring prefix;
-  JDXstring format;
+  LDRstring prefix;
+  LDRstring format;
 
 };
 
