@@ -72,15 +72,15 @@ bool RecoEpiNavScan::process(RecoData& rd, RecoController& controller) {
   }
 
 
-  int itrain=rd.coord().echotrain;
-  ODINLOG(odinlog,normalDebug) << "itrain=" << itrain << STD_endl;
+//  int itrain=rd.coord().echotrain;
+//  ODINLOG(odinlog,normalDebug) << "itrain=" << itrain << STD_endl;
 
   // Post data for each echo separately on blackboard
   RecoData one_echo_phasemap;
   one_echo_phasemap.data(Rank<1>()).resize(nread);
   one_echo_phasemap.coord()=rd.coord();
   modify4blackboard(one_echo_phasemap.coord());
-  one_echo_phasemap.coord().index[epi]=itrain;
+//  one_echo_phasemap.coord().index[epi]=itrain;
 
   for(int i=0; i<2; i++) {
     one_echo_phasemap.data(Rank<1>())=phasemap(i,all);
@@ -120,9 +120,9 @@ bool RecoEpiNavCorr::process(RecoData& rd, RecoController& controller) {
   one_echo_phasemap.coord()=rd.coord();
   RecoEpiNavScan::modify4blackboard(one_echo_phasemap.coord());
 
-  int itrain=rd.coord().echotrain;
-  ODINLOG(odinlog,normalDebug) << "itrain=" << itrain << STD_endl;
-  one_echo_phasemap.coord().index[epi]=itrain;
+//  int itrain=rd.coord().echotrain;
+//  ODINLOG(odinlog,normalDebug) << "itrain=" << itrain << STD_endl;
+//  one_echo_phasemap.coord().index[epi]=itrain;
 
 
   int iecho=bool(rd.coord().flags&recoReflectBit);
