@@ -2,7 +2,7 @@
                           expfit.h  -  description
                              -------------------
     begin                : Thu Mar 15 2007
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -31,8 +31,8 @@ class RecoExpFit : public RecoStep {
   RecoStep* allocate() const {return new RecoExpFit;}
   void init();
 
-  JDXbool  invert;
-  JDXfloat masklevel;
+  LDRbool  invert;
+  LDRfloat masklevel;
 
 };
 
