@@ -2,7 +2,7 @@
                           fft.h  -  description
                              -------------------
     begin                : Sat Dec 30 2006
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -31,7 +31,7 @@ class RecoFFT : public RecoStep {
   RecoStep* allocate() const {return new RecoFFT;}
   void init();
 
-  JDXbool forward;
+  LDRbool forward;
 };
 
 
