@@ -2,7 +2,7 @@
                           filter.h  -  description
                              -------------------
     begin                : Fri Sep 14 2007
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -20,7 +20,7 @@
 
 #include "step.h"
 
-#include <odinpara/jdxfilter.h>
+#include <odinpara/ldrfilter.h>
 
 class RecoFilter : public RecoStep {
 
@@ -33,8 +33,8 @@ class RecoFilter : public RecoStep {
   RecoStep* allocate() const {return new RecoFilter;}
   void init();
 
-  JDXfilter filter;
-  JDXfloat  plateau;
+  LDRfilter filter;
+  LDRfloat  plateau;
 
 };
 
