@@ -2,7 +2,7 @@
                           fmri.h  -  description
                              -------------------
     begin                : Thu Apr 30 2009
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -31,8 +31,8 @@ class RecoFMRI : public RecoStep {
   RecoStep* allocate() const {return new RecoFMRI;}
   void init();
 
-  JDXint stimsize;
-  JDXint restsize;
+  LDRint stimsize;
+  LDRint restsize;
 
 };
 
