@@ -17,7 +17,7 @@ ivector next_neighbours_offset(unsigned int reductionFactor, int numof_neighb, i
 
   ivector result(numof_neighb);
 
-  int negfirst=(ired<(reductionFactor/2)); // determine initial direction
+  int negfirst=(ired<int(reductionFactor/2)); // determine initial direction
 
   for(int i=0; i<numof_neighb; i++) {
     int i2=i/2;  // interleaved positive and negative direction
@@ -421,9 +421,11 @@ bool RecoGrappa<interpolDim,orthoDim,interpolIndex,orthoIndex>::process(RecoData
                     srcindex(3)=src_iread;
 
                     STD_complex srcval=kspace(srcindex);
+/*
                     if(cabs(srcval)==0.0) {
                       ODINLOG(odinlog,warningLog) << "Zero srcval at " << srcindex << " while interpolating " << kspaceindex << STD_endl;
                     }
+*/
 
                     interpolval += srcval * weights(ichan,ired,jchan,jphase,jread);  // linear interpolation of kspace
                   }
