@@ -71,17 +71,23 @@ const Gridding<STD_complex,NDim>& RecoGrid<NDim>::get_gridder(const RecoCoord& c
 
     for(int iseg=0; iseg<nseg; iseg++) {
       for(int ipt=0; ipt<npts; ipt++) {
-        const TinyVector<float,3>& kpoint=(*traj)(iseg,ipt).coord;
-        TinyVector<float,NDim>& srcpoint=srccoords[iseg*npts+ipt].coord;
+        const GriddingPoint<3>& gridpoint=(*traj)(iseg,ipt);
+        const TinyVector<float,3>& kpoint=gridpoint.coord;
+        GriddingPoint<NDim>& srccoord=srccoords[iseg*npts+ipt];
+        TinyVector<float,NDim>& srcpoint=srccoord.coord;
         for(int i=0; i<NDim; i++) {
           float k=kpoint(3-NDim+i); // Use rightmost k-space coordinate subset
           srcpoint(i)=k * appGridScale;
         }
-        srccoords[iseg*npts+ipt].weight=(*traj)(iseg,ipt).weight;
+        ODINLOG(odinlog,normalDebug) << "srcpoint=" << srcpoint << STD_endl;
+        ODINLOG(odinlog,normalDebug) << "kpoint=" << kpoint << STD_endl;
+        srccoord.weight=gridpoint.weight;
       }
     }
 
     TinyVector<float,3> kmax=controller.kspace_extent();
+    ODINLOG(odinlog,normalDebug) << "kmax=" << kmax << STD_endl;
+
     TinyVector<float,NDim> dstextent;
     for(int i=0; i<NDim; i++) dstextent(i)=kmax(3-NDim+i);
 
@@ -107,7 +113,7 @@ const Gridding<STD_complex,NDim>& RecoGrid<NDim>::get_gridder(const RecoCoord& c
     kspace_kernel_os=STD_complex(0.0);
 
     // fill k-space with gridding kernel
-    for(int i=0; i<kspace_kernel_os.size(); i++) {
+    for(unsigned int i=0; i<kspace_kernel_os.size(); i++) {
       TinyVector<int,NDim> index=kspace_kernel_os.create_index(i);
       TinyVector<int,NDim> dist=index-shape_os/2;
       float radius=secureDivision( sqrt(double(sum(dist*dist))), 0.5*deapo_os_factor*kernelwidth*appGridScale);
@@ -208,7 +214,7 @@ bool RecoDeapodize<NDim>::process(RecoData& rd, RecoController& controller) {
   ComplexData<3>& data=rd.data(Rank<3>());
   ComplexData<NDim>& deapo=rddeapo.data(Rank<NDim>());
 
-  for(int i=0; i<data.size(); i++) {
+  for(unsigned int i=0; i<data.size(); i++) {
     TinyVector<int,3> index=data.create_index(i);
 
     TinyVector<int,NDim> deapoindex;
