@@ -2,7 +2,7 @@
                           mip.h  -  description
                              -------------------
     begin                : Tue Dec 4 2007
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -32,7 +32,7 @@ class RecoMip : public RecoStep {
   RecoStep* allocate() const {return new RecoMip;}
   void init();
 
-  JDXint neighbors;
+  LDRint neighbors;
 
 };
 
