@@ -210,7 +210,7 @@ bool RecoFreqComb::process(RecoData& rd, RecoController& controller) {
 
   Data<float,1> freqs;
   if(!get_freqs(freqs, fmapcoord, controller)) return false;
-  if(nfreq!=freqs.size()) {
+  if(nfreq!=int(freqs.size())) {
     ODINLOG(odinlog,errorLog) << "nfreq=" << nfreq << "!=" << freqs.size() << STD_endl;
     return false;
   }
