@@ -2,7 +2,7 @@
                           multifreq.h  -  description
                              -------------------
     begin                : Wed Jun 6 2007
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -33,7 +33,7 @@ class RecoMultiFreq : public RecoStep {
   RecoStep* allocate() const {return new RecoMultiFreq;}
   void init();
 
-  JDXint max_numof_freq;
+  LDRint max_numof_freq;
 
 
   bool get_freqs(Data<float,1>& result, const RecoCoord& fmapcoord, double adcdur, RecoController& controller);
