@@ -2,7 +2,7 @@
                           pilot.h  -  description
                              -------------------
     begin                : Tue Mar 14 2007
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -34,7 +34,7 @@ class RecoPilot : public RecoStep {
 
   void transpose_inplane(ComplexData<5>& data, Geometry& geo, bool reverse_read, bool reverse_phase);
 
-  JDXfloat slicedist;
+  LDRfloat slicedist;
 };
 
 
