@@ -2,7 +2,7 @@
                           reader_custom.h  -  description
                              -------------------
     begin                : Thu Oct 18 2007
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -34,7 +34,7 @@
 class RecoReaderCustom : public virtual RecoReaderInterface {
 
  public:
-  RecoReaderCustom(JcampDxBlock&) {}
+  RecoReaderCustom(LDRblock&) {}
 
  private:
 
