@@ -2,7 +2,7 @@
                           reader_odin.h  -  description
                              -------------------
     begin                : Thu Oct 18 2007
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -34,7 +34,7 @@
 class RecoReaderOdin : public virtual RecoReaderInterface {
 
  public:
-  RecoReaderOdin(JcampDxBlock& parblock);
+  RecoReaderOdin(LDRblock& parblock);
   ~RecoReaderOdin();
 
  private:
@@ -60,8 +60,8 @@ class RecoReaderOdin : public virtual RecoReaderInterface {
 
   template<typename T2> bool read_block(T2 dummy, ComplexData<2>& block);
 
-  JDXstring fifoFile;
-  JDXbool   padZero;
+  LDRstring fifoFile;
+  LDRbool   padZero;
 
   // read only in fetch()
   unsigned int nadc;
