@@ -2,7 +2,7 @@
                           refgain.h  -  description
                              -------------------
     begin                : Thu Feb 22 2007
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -31,8 +31,8 @@ class RecoRefGain : public RecoStep {
   RecoStep* allocate() const {return new RecoRefGain;}
   void init();
 
-  JDXfloat pulsedur;
-  JDXfloat pulsegain;
+  LDRfloat pulsedur;
+  LDRfloat pulsegain;
 };
 
 
