@@ -2,7 +2,7 @@
                           store.h  -  description
                              -------------------
     begin                : Sat Dec 30 2006
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -42,11 +42,11 @@ class RecoStore : public RecoStep {
   RecoStep* allocate() const {return new RecoStore;}
   void init();
 
-  JDXstring extension;
-  JDXstring prefix;
-  JDXstring formats;
-  JDXstring imageproc;
-  JDXbool   storephase;
+  LDRstring extension;
+  LDRstring prefix;
+  LDRstring formats;
+  LDRstring imageproc;
+  LDRbool   storephase;
   FileWriteOpts wopts; // for access to some autowrite opts
 
   bool store_images(const RecoController& controller);
