@@ -2,7 +2,7 @@
                           switch.h  -  description
                              -------------------
     begin                : Mon Jan 22 2007
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -35,7 +35,7 @@ class RecoSwitch : public RecoStep {
   void init();
 
 
-  JDXstring brancharg;
+  LDRstring brancharg;
 
 
   struct BranchKey {
