@@ -123,8 +123,10 @@ bool RecoT1Fit::process(RecoData& rd, RecoController& controller) {
   InversionRecoveryAbsFunction irabsfunc;
   irabsfunc.fitphi=false;
 
-  FunctionFit irfit(irfunc,ntis);
-  FunctionFit irabsfit(irabsfunc,ntis);
+  FunctionFitDerivative irfit;
+  if(!irfit.init(irfunc,ntis)) return false;
+  FunctionFitDerivative irabsfit;
+  if(!irabsfit.init(irabsfunc,ntis)) return false;
 
   Data<float,3> T1map(outshape); T1map=0.0;
   Data<float,3> S0map(outshape); S0map=0.0;
