@@ -2,7 +2,7 @@
                           t1fit.h  -  description
                              -------------------
     begin                : Thu Mar 15 2007
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -31,9 +31,9 @@ class RecoT1Fit : public RecoStep {
   RecoStep* allocate() const {return new RecoT1Fit;}
   void init();
 
-  JDXstring fittype;
-  JDXfloat masklevel;
-  JDXfloat maxt1;
+  LDRstring fittype;
+  LDRfloat masklevel;
+  LDRfloat maxt1;
 
 };
 
