@@ -2,7 +2,7 @@
                           zerofill.h  -  description
                              -------------------
     begin                : Wed Oct 10 2007
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -31,9 +31,9 @@ class RecoZeroFill : public RecoStep {
   RecoStep* allocate() const {return new RecoZeroFill;}
   void init();
 
-  JDXint minread;
-  JDXint minphase;
-  JDXint minslice;
+  LDRint minread;
+  LDRint minphase;
+  LDRint minslice;
 
 
 };
