@@ -2,7 +2,7 @@
                           odinpulse.h  -  description
                              -------------------
     begin                : Tue Jun 4 2002
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -18,8 +18,8 @@
 #ifndef ODINPULSE_H
 #define ODINPULSE_H
 
-#include <odinpara/jdxfunction.h>
-#include <odinpara/jdxfilter.h>
+#include <odinpara/ldrfunction.h>
+#include <odinpara/ldrfilter.h>
 
 #include <odinseq/seqpuls.h>
 
@@ -48,14 +48,14 @@ class Sample;  // forward declaration
   *
   * Wrapper class for trajectory functions.
   */
-class JDXtrajectory : public JDXfunction,  public StaticHandler<JDXtrajectory> {
+class LDRtrajectory : public LDRfunction,  public StaticHandler<LDRtrajectory> {
 
  public:
-  JDXtrajectory(const STD_string& jdxlabel="unnamedJDXtrajectory") : JDXfunction(trajFunc,jdxlabel) {}
+  LDRtrajectory(const STD_string& ldrlabel="unnamedLDRtrajectory") : LDRfunction(trajFunc,ldrlabel) {}
 
-  JDXtrajectory(const JDXtrajectory& jt) : JDXfunction(jt) {}
+  LDRtrajectory(const LDRtrajectory& jt) : LDRfunction(jt) {}
 
-  JDXtrajectory& operator = (const JDXtrajectory& jt) {JDXfunction::operator = (jt); return *this;}
+  LDRtrajectory& operator = (const LDRtrajectory& jt) {LDRfunction::operator = (jt); return *this;}
 
   void init_trajectory(OdinPulse* pls=0) {if(allocated_function) allocated_function->init_trajectory(pls);}
 
@@ -74,14 +74,14 @@ class JDXtrajectory : public JDXfunction,  public StaticHandler<JDXtrajectory> {
   *
   * Wrapper class for pulse shape functions.
   */
-class JDXshape : public JDXfunction,  public StaticHandler<JDXshape> {
+class LDRshape : public LDRfunction,  public StaticHandler<LDRshape> {
 
  public:
-  JDXshape(const STD_string& jdxlabel="unnamedJDXshape") : JDXfunction(shapeFunc,jdxlabel) {}
+  LDRshape(const STD_string& ldrlabel="unnamedLDRshape") : LDRfunction(shapeFunc,ldrlabel) {}
 
-  JDXshape(const JDXshape& js) : JDXfunction(js) {}
+  LDRshape(const LDRshape& js) : LDRfunction(js) {}
 
-  JDXshape& operator = (const JDXshape& js) {JDXfunction::operator = (js); return *this;}
+  LDRshape& operator = (const LDRshape& js) {LDRfunction::operator = (js); return *this;}
 
   void init_shape() {if(allocated_function) allocated_function->init_shape();}
 
@@ -119,7 +119,7 @@ struct OdinPulseData; // forward declaration
   * This class represents an advanced RF pulse. The RF and gradient
   * shape will be calculated according to a set of given parameters.
   */
-class OdinPulse : public JcampDxBlock, public virtual SeqClass {
+class OdinPulse : public LDRblock, public virtual SeqClass {
 
  public:
 
@@ -497,9 +497,8 @@ class OdinPulse : public JcampDxBlock, public virtual SeqClass {
   int load_rf_waveform (const STD_string& filename);
 
 
-  // overloading virtual functions of JcampDxBlock
-  int load(const STD_string& filename);
-  int write(const STD_string& filename) const;
+  // overloading virtual functions of LDRblock
+  int load(const STD_string& filename, const LDRserBase& serializer=LDRserJDX());
 
 
  protected:
