@@ -2,7 +2,7 @@
                           seqacqepi.h  -  description
                              -------------------
     begin                : Wed Aug 8 2001
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -296,7 +296,7 @@ class SeqAcqEPI : public SeqObjBase, public virtual SeqAcqInterface, public virt
   double get_duration() const {return driver->get_duration();}
   SeqValList get_freqvallist(freqlistAction action) const {return driver->get_freqvallist(action);}
   void query(queryContext& context) const {driver->query(context);}
-  RecoValList get_recovallist(unsigned int reptimes, JDXkSpaceCoords& coords) const;
+  RecoValList get_recovallist(unsigned int reptimes, LDRkSpaceCoords& coords) const;
   bool contains(const SeqTreeObj* sto) const {return driver->contains(sto);}
   void tree(SeqTreeCallbackAbstract* display) const {driver->tree(display);}
   unsigned int event(eventContext& context) const {return driver->event(context);}
