@@ -2,7 +2,7 @@
                           seqacqspiral.h  -  description
                              -------------------
     begin                : Tue Nov 11 2003
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -57,7 +57,7 @@ class SeqAcqSpiral : public virtual SeqAcqInterface, public SeqObjList  {
   * - phaselist:   See class 'SeqAcq' for explanation
   */
   SeqAcqSpiral(const STD_string& object_label,double sweepwidth, float fov,
-             unsigned int sizeRadial, unsigned int numofSegments, JDXtrajectory&  traj,
+             unsigned int sizeRadial, unsigned int numofSegments, LDRtrajectory&  traj,
              bool inout=false, bool optimize=false, const STD_string& nucleus="",const dvector& phaselist=0);
 
 
