@@ -59,7 +59,8 @@ SeqGradEcho::SeqGradEcho(const STD_string& object_label,
               unsigned int readnpts, float FOVread, unsigned int phasenpts, float FOVphase, unsigned int slicenpts, float FOVslice,
               SeqPulsar& exc, double sweepwidth,
               unsigned int reduction, unsigned int acl_bands,
-              bool balanced, float partial_fourier_phase, float partial_fourier_read, bool partial_fourier_read_at_end, float os_factor, const STD_string& nucleus) :
+              bool balanced, float partial_fourier_phase, float partial_fourier_phase3d,
+              float partial_fourier_read, bool partial_fourier_read_at_end, float os_factor, const STD_string& nucleus) :
  SeqObjList(object_label),
  pls_reph(object_label+"_exc_reph",exc),
  acqread(object_label+"_acqread", sweepwidth, readnpts, FOVread, readDirection, os_factor, partial_fourier_read, partial_fourier_read_at_end, nucleus) {
@@ -84,19 +85,24 @@ SeqGradEcho::SeqGradEcho(const STD_string& object_label,
 
   // use SeqGradPhaseEnc to initialize phase encoding
   SeqGradPhaseEnc pedummy3d(object_label+"_phase3d", slicenpts, FOVslice, constdur, sliceDirection,
-                                 linearEncoding, noReorder, 1, reduction, acl_bands, 0.0, nucleus);
-  phase3d=pedummy3d.vectorgrad;
+                                 linearEncoding, noReorder, 1, reduction, acl_bands, partial_fourier_phase3d, nucleus);
+//  phase3d=pedummy3d.vectorgrad;
+  ODINLOG(odinlog,normalDebug) << "pedummy3d.get_trims()=" << pedummy3d.get_trims() << STD_endl;
 
   // Merge slice rephaser and 2nd phase encoding
-  float integral_phase3d=phase3d.get_strength()*phase3d.get_gradduration();
+  float integral_phase3d=pedummy3d.vectorgrad.get_strength()*pedummy3d.vectorgrad.get_gradduration();
   float integral_reph=pls_reph.get_gradintegral()[sliceDirection];
-  fvector integrals_slice = phase3d.get_trims()*integral_phase3d + integral_reph;
+  fvector integrals_slice = pedummy3d.vectorgrad.get_trims()*integral_phase3d + integral_reph;
   ODINLOG(odinlog,normalDebug) << "integrals_slice=" << integrals_slice << STD_endl;
   float maxabsintegral_slice=integrals_slice.maxabs();
   float strength_slice=secureDivision(maxabsintegral_slice, constdur);
   fvector trims_slice(integrals_slice/maxabsintegral_slice);
-  phase3d=SeqGradVector("phase3d", sliceDirection, strength_slice, trims_slice, constdur);
+  phase3d=SeqGradVector(object_label+"_phase3d", sliceDirection, strength_slice, trims_slice, constdur);
 
+  // Copy indevec manually after merge
+  ivector index3dvec=((const SeqVector&)pedummy3d).get_indexvec();
+  ODINLOG(odinlog,normalDebug) << "index3dvec=" << index3dvec << STD_endl;
+  phase3d.set_indexvec(index3dvec);
 
 
   if(balanced_grads) {
