@@ -189,7 +189,7 @@ void SeqObjList::query(queryContext& context) const {
 
 
 
-RecoValList SeqObjList::get_recovallist(unsigned int reptimes, JDXkSpaceCoords& coords) const {
+RecoValList SeqObjList::get_recovallist(unsigned int reptimes, LDRkSpaceCoords& coords) const {
   Log<Seq> odinlog(this,"get_recovallist");
   RecoValList result(get_label());
   for(constiter it=get_const_begin();it!=get_const_end();++it) {
