@@ -2,7 +2,7 @@
                           seqlist.h  -  description
                              -------------------
     begin                : Wed Aug 14 2002
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -175,7 +175,7 @@ class SeqObjList : public SeqObjBase, public List<SeqObjBase, const SeqObjBase*,
   double get_duration() const;
   STD_string get_properties() const;
   void query(queryContext& context) const;
-  RecoValList get_recovallist(unsigned int reptimes, JDXkSpaceCoords& coords) const;
+  RecoValList get_recovallist(unsigned int reptimes, LDRkSpaceCoords& coords) const;
   SeqValList get_freqvallist(freqlistAction action) const;
   SeqValList get_delayvallist() const;
   double get_rf_energy() const;
