@@ -2,7 +2,7 @@
                           seqmakefile.h  -  description
                              -------------------
     begin                : Wed Apr 14 2004
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -54,7 +54,7 @@ private:
   STD_string get_methlabel() const {return get_label();}
   STD_string get_methdefines(const STD_string& main, const STD_string& classlabel) const;
 
-  JDXfileName inst_prefix;
+  LDRfileName inst_prefix;
   STD_string cxx;
   STD_string cxxflags;
   STD_string ld;
