@@ -48,7 +48,9 @@ class CatchSegFaultContext : public StaticHandler<CatchSegFaultContext> {
     sa.sa_restorer=0;
 #endif
 */
-    if(sigaction(SIGSEGV,&sa,0)) ODINLOG(odinlog,errorLog) << "unable to register segfaultHandler for " << (*label) << STD_endl;
+    if(sigaction(SIGSEGV,&sa,0)) {
+      ODINLOG(odinlog,errorLog) << "unable to register segfaultHandler for " << (*label) << STD_endl;
+    }
   }
 
   ~CatchSegFaultContext() {
@@ -393,10 +395,11 @@ SeqMethod::~SeqMethod() {
 }
 
 
-SeqMethod& SeqMethod::append_parameter(JcampDxClass& ldr,const STD_string& label,parameterMode parmode) {
+SeqMethod& SeqMethod::append_parameter(LDRbase& ldr,const STD_string& label,parameterMode parmode) {
   ldr.set_label(label);
 
-  JcampDxBlock* blockdum=ldr.cast(blockdum);
+  LDRblock* blockdum=0; // avoid compiler warning
+  blockdum=ldr.cast(blockdum);
   if(!blockdum) ldr.set_parmode(parmode); // Do not change parmode of a whole block
 
   if(methodPars) methodPars->append(ldr);
@@ -492,7 +495,7 @@ SeqMethod& SeqMethod::init_systemInfo(double basicfreq,double maxgrad,double sle
 
 int SeqMethod::write_recoInfo(const STD_string& filename) const {
   create_protcache();
-  recoInfo->prot.clear(); // Clear and merge instead of assignment to work around bug in assignment of JDX on MinGW
+  recoInfo->prot.clear(); // Clear and merge instead of assignment to work around bug in assignment of LDR on MinGW
   recoInfo->prot.merge(*protcache);
   return recoInfo->write(filename);
 }
@@ -532,7 +535,7 @@ int SeqMethod::load_sequencePars(const STD_string& filename) {
 }
 
 int SeqMethod::write_sequencePars(const STD_string& filename) const {
-  JcampDxBlock block( (STD_string(get_label())+"_sequencePars") );
+  LDRblock block( (STD_string(get_label())+"_sequencePars") );
   if(commonPars) block.merge(*commonPars);
   if(methodPars) block.merge(*methodPars);
   return block.write(filename);
@@ -545,12 +548,12 @@ bool SeqMethod::set_sequenceParameter(const STD_string& parameter_label, const S
 
   // first send it to common pars without prefix
   STD_string parlabel=parameter_label;
-  if(commonPars) if(commonPars->JcampDxBlock::parseval(parlabel,value)) result=true;
+  if(commonPars) if(commonPars->LDRblock::parseval(parlabel,value)) result=true;
 
   // then send it to method pars with prefix
   STD_string prefixstr=STD_string(get_label())+"_";
   if(parameter_label.find(prefixstr)!=0) parlabel=prefixstr+parameter_label;
-  if(methodPars) if(methodPars->JcampDxBlock::parseval(parlabel,value)) result=true;
+  if(methodPars) if(methodPars->LDRblock::parseval(parlabel,value)) result=true;
 
   return result;
 }
@@ -591,7 +594,7 @@ unsigned int SeqMethod::event(eventContext& context) const {
 }
 
 
-void SeqMethod::parameter_relations(JDXeditWidget* editwidget) {
+void SeqMethod::parameter_relations(LDReditWidget* editwidget) {
 #ifdef GUISUPPORT
   clear();
   build();
@@ -697,7 +700,7 @@ bool SeqMethod::empty2initialised() {
   }
 
   if(!methodPars) {
-    methodPars=new JcampDxBlock();
+    methodPars=new LDRblock();
 
     CATCHSEGFAULT(method_pars_init(),"method_pars_init")
 
