@@ -2,7 +2,7 @@
                           seqmeth.h  -  description
                              -------------------
     begin                : Thu Aug 9 2001
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -152,7 +152,7 @@ class SeqMethodProxy : public StaticHandler<SeqMethodProxy> {
   * To get an idea what has to be done in each function, please take a
   * look at the example sequences.
   */
-class SeqMethod : protected SeqMethodProxy, public SeqObjList, public virtual JDXeditCaller, public StateMachine<SeqMethod> {
+class SeqMethod : protected SeqMethodProxy, public SeqObjList, public virtual LDReditCaller, public StateMachine<SeqMethod> {
 
 
  public:
@@ -230,7 +230,7 @@ class SeqMethod : protected SeqMethodProxy, public SeqObjList, public virtual JD
 /**
   * Returns the method-specific parameters
   */
-  JcampDxBlock& get_methodPars() {return *methodPars;}
+  LDRblock& get_methodPars() {return *methodPars;}
 
 /**
   * Loads the sequence parameters (commonPars & methodPars) from file
@@ -367,7 +367,7 @@ class SeqMethod : protected SeqMethodProxy, public SeqObjList, public virtual JD
 /**
   * Append a user defined parameter to the list of parameters that describe the method
   */
-  SeqMethod& append_parameter(JcampDxClass& ldr,const STD_string& label,parameterMode parmode=edit);
+  SeqMethod& append_parameter(LDRbase& ldr,const STD_string& label,parameterMode parmode=edit);
 
 /**
   * This function is used to specify the sequence of this method that will be played out
@@ -408,14 +408,14 @@ class SeqMethod : protected SeqMethodProxy, public SeqObjList, public virtual JD
   bool calc_timings();
 
 
-  // overloaded virtual function from JDXeditCaller
-  void parameter_relations(JDXeditWidget* editwidget);
+  // overloaded virtual function from LDReditCaller
+  void parameter_relations(LDReditWidget* editwidget);
 
   // interface for quick access to current platform
   mutable SeqPlatformProxy platform;
 
   // block to hold method-specific parameters
-  JcampDxBlock* methodPars;
+  LDRblock* methodPars;
 
   STD_string description;
 
