@@ -2,7 +2,7 @@
                           seqobjvec.h  -  description
                              -------------------
     begin                : Mon Aug 9 2004
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -85,7 +85,7 @@ class SeqObjVector : public SeqVector, public SeqObjBase, public List<SeqObjBase
   double get_duration() const;
   unsigned int event(eventContext& context) const;
   void query(queryContext& context) const;
-  RecoValList get_recovallist(unsigned int reptimes, JDXkSpaceCoords& coords) const;
+  RecoValList get_recovallist(unsigned int reptimes, LDRkSpaceCoords& coords) const;
   SeqValList get_freqvallist(freqlistAction action) const;
   SeqValList get_delayvallist() const;
   double get_rf_energy() const;
