@@ -151,7 +151,7 @@ void SeqParallel::query(queryContext& context) const {
 }
 
 
-RecoValList SeqParallel::get_recovallist(unsigned int reptimes, JDXkSpaceCoords& coords) const {
+RecoValList SeqParallel::get_recovallist(unsigned int reptimes, LDRkSpaceCoords& coords) const {
   RecoValList result(get_label());
   const SeqObjBase* soa=get_pulsptr();
   if(soa) result=soa->get_recovallist(reptimes,coords);
