@@ -2,7 +2,7 @@
                           seqparallel.h  -  description
                              -------------------
     begin                : Fri Apr 16 2004
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -117,7 +117,7 @@ class SeqParallel : public SeqObjBase, public virtual SeqGradInterface {
   SeqValList get_freqvallist(freqlistAction action) const;
   SeqValList get_delayvallist() const;
   void query(queryContext& context) const;
-  RecoValList get_recovallist(unsigned int reptimes, JDXkSpaceCoords& coords) const;
+  RecoValList get_recovallist(unsigned int reptimes, LDRkSpaceCoords& coords) const;
   double get_rf_energy() const;
 
 
