@@ -94,7 +94,7 @@ void SeqSimMagsi::outdate_simcache() {
 }
 
 
-SeqSimMagsi::SeqSimMagsi(const STD_string& label) : JcampDxBlock(label) {
+SeqSimMagsi::SeqSimMagsi(const STD_string& label) : LDRblock(label) {
   SeqClass::set_label(label);
   common_init();
 
@@ -134,7 +134,7 @@ int SeqSimMagsi::append_all_members() {
 
 SeqSimMagsi& SeqSimMagsi::operator = (const SeqSimMagsi& ssm) {
   SeqClass::set_label(ssm.SeqClass::get_label());
-  JcampDxBlock::operator = (ssm);
+  LDRblock::operator = (ssm);
 
   Mx=ssm.Mx;
   My=ssm.My;
@@ -418,8 +418,9 @@ void SeqSimMagsi::prepare_simulation(const Sample& sample, CoilSensitivity* tran
 
   B0_ppm=1.0e-6*systemInfo->get_B0();
 
-  if(spat_rotmatrix) ODINLOG(odinlog,normalDebug) << "spat_rotmatrix=" << spat_rotmatrix->print() << STD_endl;
-
+  if(spat_rotmatrix) {
+    ODINLOG(odinlog,normalDebug) << "spat_rotmatrix=" << spat_rotmatrix->print() << STD_endl;
+  }
 
   ODINLOG(odinlog,normalDebug) << "ppmMap.get_extent()=" << ppmMap.get_extent() << STD_endl;
   ODINLOG(odinlog,normalDebug) << "spinDensity.get_extent()=" << spinDensity.get_extent() << STD_endl;
@@ -610,8 +611,8 @@ bool SeqSimMagsi::kernel(const SeqSimInterval& simvals, cvector& signal, int&, u
   unsigned int ichan;
 
   // doubles to sum up signal, and use local (thread-specific) storage
-  double* reSig;
-  double* imSig;
+  double* reSig=0;
+  double* imSig=0;
   if(simvals.rec>0.0) {
     reSig=new double[num_rec_channel_cache];
     imSig=new double[num_rec_channel_cache];
