@@ -2,7 +2,7 @@
                           seqtemplate.h  -  description
                              -------------------
     begin                : Mon Tue 23 2005
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -81,7 +81,7 @@ class SeqFieldMap : public SeqObjList {
 /**
   * Returns block of local parameters
   */
-  JcampDxBlock& get_parblock();
+  LDRblock& get_parblock();
 
 };
 
