@@ -2,7 +2,7 @@
                           seqpuls_standalone.h  -  description
                              -------------------
     begin                : Sat Apr 3 2004
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -39,7 +39,7 @@ class SeqPulsStandAlone : public SeqPulsDriver, public SeqStandAlone {
   // overloading virtual functions from SeqPulsDriver
   bool prep_driver(const cvector& wave, double pulsduration, double pulscenter, float b1max, float power, float flipangle, const fvector& flipscales, pulseType plstype);
   void event(eventContext& context, double start) const;
-  double get_rf_energy() const {return rf_energy[current_pls];}
+  double get_rf_energy() const;
   bool prep_flipangle_iteration(unsigned int count);
   double get_predelay() const {return 0.0;}
   double get_postdelay() const {return 0.0;}
