@@ -130,13 +130,13 @@ void PulsarView::updatePulse() {
   ODINLOG(odinlog,normalDebug) << "old_mode/mode=" << old_mode << "/" << mode << STD_endl;
   if(old_mode!=mode) {
     if(old_mode!=n_dimModes) {
-      ODINLOG(odinlog,normalDebug) << "Hiding old JDXwidget" << STD_endl;
+      ODINLOG(odinlog,normalDebug) << "Hiding old LDRwidget" << STD_endl;
       pulseWidget[old_mode]->deleteDialogs();
       pulseWidget[old_mode]->hide();
     }
-    ODINLOG(odinlog,normalDebug) << "Allocating JDXwidget" << STD_endl;
-    if(pulseWidget[mode]==0) pulseWidget[mode]=new JDXwidget(*pulse,2,this,true);
-    ODINLOG(odinlog,normalDebug) << "Showing JDXwidget" << STD_endl;
+    ODINLOG(odinlog,normalDebug) << "Allocating LDRwidget" << STD_endl;
+    if(pulseWidget[mode]==0) pulseWidget[mode]=new LDRwidget(*pulse,2,this,true);
+    ODINLOG(odinlog,normalDebug) << "Showing LDRwidget" << STD_endl;
     pulseWidget[mode]->show();
     grid->add_widget(pulseWidget[mode], 0, 0, GuiGridLayout::Default, 2, 1);
     connect(pulseWidget[mode],SIGNAL(valueChanged()),this,SLOT(updatePulse()));
@@ -184,7 +184,7 @@ void PulsarView::updateMagnetization() {
     }
     if(sampleWidget[mode]==0) {
       ODINLOG(odinlog,normalDebug) << "Creating new sampleWidget ..." << STD_endl;
-      sampleWidget[mode]=new JDXwidget(*sample,1,this);
+      sampleWidget[mode]=new LDRwidget(*sample,1,this);
       sampleWidget[mode]->show();
       grid->add_widget(sampleWidget[mode], 0, 1);
       connect(sampleWidget[mode],SIGNAL(valueChanged()),this,SLOT(updateMagnetization()));
@@ -192,7 +192,7 @@ void PulsarView::updateMagnetization() {
     }
     if(magnWidget[mode]==0) {
       ODINLOG(odinlog,normalDebug) << "Creating new magnWidget ..." << STD_endl;
-      magnWidget[mode]=new JDXwidget(*mag,1,this);
+      magnWidget[mode]=new LDRwidget(*mag,1,this);
       magnWidget[mode]->show();
       grid->add_widget(magnWidget[mode], 1, 1);
       connect(magnWidget[mode],SIGNAL(valueChanged()),this,SLOT(updateMagnetization()));
@@ -288,7 +288,7 @@ void PulsarView::exportMampASCII() {exportASCIImag(mag->get_Mamp());}
 void PulsarView::exportMphaASCII() {exportASCIImag(mag->get_Mpha());}
 void PulsarView::exportMzASCII() {exportASCIImag(mag->get_Mz());}
 
-void PulsarView::exportPulseJDX() {
+void PulsarView::exportPulseLDR() {
   STD_string fname=get_save_filename("Export JCAMP-DX Pulse", "", "", this);
   if(fname!="") {
     OdinPulse sd(*pulse);
@@ -297,7 +297,7 @@ void PulsarView::exportPulseJDX() {
   }
 }
 
-void PulsarView::exportMagJDX() {
+void PulsarView::exportMagLDR() {
   STD_string fname=get_save_filename("Export JCAMP-DX Magnetization", "", "", this);
   if(fname!="") {
     SeqSimMagsi sm(*mag);
@@ -307,7 +307,7 @@ void PulsarView::exportMagJDX() {
 }
 
 void PulsarView::edit_systemInfo() {
-  JDXwidgetDialog* dlg=new JDXwidgetDialog(pulse->get_systemInfo(),1,this);
+  LDRwidgetDialog* dlg=new LDRwidgetDialog(pulse->get_systemInfo(),1,this);
   connect(dlg,SIGNAL(valueChanged()),this,SLOT(updatePulse()));
 }
 
