@@ -2,7 +2,7 @@
                           pulsarview.h  -  description
                              -------------------
     begin                : Thu Jun 20 19:02:26 CEST 2002
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -18,8 +18,8 @@
 #ifndef PULSARVIEW_H
 #define PULSARVIEW_H
 
-#include <odinqt/jdxwidget.h>
-#include <odinqt/jdxblockwidget.h>
+#include <odinqt/ldrwidget.h>
+#include <odinqt/ldrblockwidget.h>
 
 #include <odinseq/odinpulse.h>
 #include <odinseq/seqsim.h>
@@ -39,7 +39,7 @@ struct PulsarCancel {}; // exception
 ////////////////////////////////////////
 
 
-class PulsarView : public QWidget, public virtual JDXeditWidget {
+class PulsarView : public QWidget, public virtual LDReditWidget {
  Q_OBJECT
 
  public:
@@ -69,8 +69,8 @@ class PulsarView : public QWidget, public virtual JDXeditWidget {
   void exportMampASCII();
   void exportMphaASCII();
   void exportMzASCII();
-  void exportPulseJDX();
-  void exportMagJDX();
+  void exportPulseLDR();
+  void exportMagLDR();
 
   void edit_systemInfo();
 
@@ -82,7 +82,7 @@ class PulsarView : public QWidget, public virtual JDXeditWidget {
 
  private:
 
-  //  Implemented function of JDXeditWidget
+  //  Implemented function of LDReditWidget
   void updateWidget();
 
   void vriteArray(const STD_string& filename, const fvector& data);
@@ -99,9 +99,9 @@ class PulsarView : public QWidget, public virtual JDXeditWidget {
 
   GuiGridLayout *grid;
 
-  JDXwidget* pulseWidget[n_dimModes];
-  JDXwidget* sampleWidget[n_dimModes];
-  JDXwidget* magnWidget[n_dimModes];
+  LDRwidget* pulseWidget[n_dimModes];
+  LDRwidget* sampleWidget[n_dimModes];
+  LDRwidget* magnWidget[n_dimModes];
 
   GuiProgressDialog* progress;
   int progcount;
