@@ -12,22 +12,22 @@ private:
   // the following parameters are specific to EPI sequences,
   // parameters common to all sequences can be accessed via the
   // 'commonPars' global object
-  JDXbool   TakeMinEchoTime;
-  JDXenum   SliceTimingMode;
-  JDXenum   TemplateScan;
-  JDXbool   RampSampling;
-  JDXenum   RampMode;
-  JDXfloat  RampSteepness;
-  JDXbool   FatSaturation;
-  JDXenum   EPIMode;
-  JDXint    Shots;
-  JDXint    DummyCycles;
-  JDXint    NumOfGradEchoes;
-  JDXint    NumOfSamples;
-  JDXdouble PulseDur;
-  JDXbool   fMRITrigger;
-  JDXint    fMRIBlockSize;
-  JDXbool   FieldMap;
+  LDRbool   TakeMinEchoTime;
+  LDRenum   SliceTimingMode;
+  LDRenum   TemplateScan;
+  LDRbool   RampSampling;
+  LDRenum   RampMode;
+  LDRfloat  RampSteepness;
+  LDRbool   FatSaturation;
+  LDRenum   EPIMode;
+  LDRint    Shots;
+  LDRint    DummyCycles;
+  LDRint    NumOfGradEchoes;
+  LDRint    NumOfSamples;
+  LDRdouble PulseDur;
+  LDRbool   fMRITrigger;
+  LDRint    fMRIBlockSize;
+  LDRbool   FieldMap;
 
 
   // sequence objects which are the elementary objects
