@@ -34,8 +34,8 @@ class METHOD_CLASS : public SeqMethod {
   SeqObjLoop dummyloop;
 
 
-  JDXint  DummyCycles;
-  JDXenum PhaseEncoding;
+  LDRint  DummyCycles;
+  LDRenum PhaseEncoding;
 
  public:
 
@@ -110,7 +110,7 @@ class METHOD_CLASS : public SeqMethod {
 
 
 
-    //////////////// Balanced Gradient Echo Module: //////////////
+    //////////////// Balanced Gradient Echo Module (2D mode): //////////////
 
     grech=SeqGradEcho("grech", exc, commonPars->get_AcqSweepWidth(),
                 commonPars->get_MatrixSize(readDirection), geometryInfo->get_FOV(readDirection),
