@@ -28,13 +28,14 @@ class METHOD_CLASS : public SeqMethod {
   void method_seq_init();
   void method_rels();
   void method_pars_set();
+  unsigned int numof_testcases() const {return 2;}
 
  private:
 
   // Parameters for this method:
-  JDXfloat T1Ernst;
-  JDXint   DummyCycles;
-  JDXfloat PartialFourierRead;
+  LDRfloat T1Ernst;
+  LDRint   DummyCycles;
+  LDRfloat PartialFourierRead;
 
   // Sequence objects for this method:
   SeqPulsar exc;
@@ -101,6 +102,14 @@ void METHOD_CLASS::method_pars_init() {
   PartialFourierRead=0.0;
   PartialFourierRead.set_description("The amount of partial Fourier undersampling in readout direction (0=no undersampling, 1=half fourier)");
 
+
+  // alternative default settings for sequence test
+  if(get_current_testcase()==1) {
+    geometryInfo->set_Mode(voxel_3d);
+    commonPars->set_PartialFourier(0.7);
+  }
+
+
   // Make method specific parameters visible in the user interface
   append_parameter(T1Ernst,"T1Ernst");
   append_parameter(DummyCycles,"DummyCycles");
@@ -174,7 +183,7 @@ void METHOD_CLASS::method_seq_init() {
               commonPars->get_MatrixSize(sliceDirection), geometryInfo->get_FOV(sliceDirection),
               exc, commonPars->get_AcqSweepWidth(),
               commonPars->get_ReductionFactor(), DEFAULT_ACL_BANDS, false,
-              commonPars->get_PartialFourier(),PartialFourierRead);
+              commonPars->get_PartialFourier(),commonPars->get_PartialFourier(),PartialFourierRead);
 
   } else {
 
