@@ -3,25 +3,25 @@
 class METHOD_CLASS : public SeqMethod {
 
 private:
-  JDXint    Blades;
-  JDXbool   ShortAxis;
-  JDXfloat  BladeOversampling;
-  JDXbool   TakeMinEchoTime;
-  JDXenum   TemplateScan;
-  JDXbool   RampSampling;
-  JDXenum   RampMode;
-  JDXfloat  RampSteepness;
-  JDXbool   FatSaturation;
-  JDXfloat  T1Ernst;
-  JDXenum   EPIMode;
-  JDXint    DummyCycles;
-  JDXint    NumOfGradEchoes;
-  JDXint    NumOfSamples;
-  JDXdouble PulseDur;
-  JDXbool   fMRITrigger;
-  JDXbool   UpDownBlade;
-  JDXbool   FieldMap;
-  JDXbool   InvertPartialFourier;
+  LDRint    Blades;
+  LDRbool   ShortAxis;
+  LDRfloat  BladeOversampling;
+  LDRbool   TakeMinEchoTime;
+  LDRenum   TemplateScan;
+  LDRbool   RampSampling;
+  LDRenum   RampMode;
+  LDRfloat  RampSteepness;
+  LDRbool   FatSaturation;
+  LDRfloat  T1Ernst;
+  LDRenum   EPIMode;
+  LDRint    DummyCycles;
+  LDRint    NumOfGradEchoes;
+  LDRint    NumOfSamples;
+  LDRdouble PulseDur;
+  LDRbool   fMRITrigger;
+  LDRbool   UpDownBlade;
+  LDRbool   FieldMap;
+  LDRbool   InvertPartialFourier;
 
 
   SeqPulsar  exc;
