@@ -548,8 +548,8 @@ STD_string print_table(const sarray& table) {
     return result;
   }
 
-  int ncols=table.size(0);
-  int nrows=table.size(1);
+  int ncols=table.size(1);
+  int nrows=table.size(0);
 
   int icol, irow;
 
@@ -557,16 +557,16 @@ STD_string print_table(const sarray& table) {
   ivector width(ncols); width=0;
   for(irow=0; irow<nrows; irow++) {
     for(icol=0; icol<ncols; icol++) {
-      width[icol]=STD_max(int(table(icol,irow).length()), width[icol]);
+      width[icol]=STD_max(int(table(irow,icol).length()), width[icol]);
     }
   }
 
   // Print formatted table
   for(irow=0; irow<nrows; irow++) {
     for(icol=0; icol<ncols; icol++) {
-      int nfillspaces=width[icol]-table(icol,irow).length()+1;
+      int nfillspaces=width[icol]-table(irow,icol).length()+1;
       if(icol==(ncols-1)) nfillspaces=0; // do not pad at end
-      result+=table(icol,irow)+STD_string(nfillspaces,' ');
+      result+=table(irow,icol)+STD_string(nfillspaces,' ');
     }
     result+="\n";
   }
