@@ -2,7 +2,7 @@
                           tjvector.h  -  description
                              -------------------
     begin                : Thu Feb 22 2001
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -336,9 +336,11 @@ public:
 
 /**
   *
-  * returns the elements of the array as a formatted string
+  * prints array to the stream s
   */
-  STD_string printbody() const;
+  friend STD_ostream& operator << (STD_ostream& s, const tjarray<V,T> &ta) {
+    return s << ta.get_extent() << "=" << ta.printbody();
+  }
 
 
 /**
@@ -348,10 +350,6 @@ public:
   ndim create_index(unsigned long index) const;
 
 
- protected:
-
-  STD_ostream& printbody2stream(STD_ostream& s) const; // required for JDX arrays
-
 
  private:
 
