@@ -2,7 +2,7 @@
                           tjcstd.h  -  description
                              -------------------
     begin                : Thu Jun 16 2004
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -43,12 +43,14 @@
 // missing C functions
 
 #ifndef HAVE_CTYPE_H
-int isdigit (int c);
-int isspace (int c);
-int islower (int c);
-int tolower (int c);
-int isupper (int c);
-int toupper (int c);
+int isdigit(int c);
+int isalpha(int c);
+int isalnum(int c);
+int isspace(int c);
+int islower(int c);
+int tolower(int c);
+int isupper(int c);
+int toupper(int c);
 #endif
 
 
