@@ -2,6 +2,8 @@
 #include "tjtest.h"
 #include "tjlog_code.h"
 
+#ifndef NO_PROCESSHANDLING
+
 #ifdef USING_WIN32
 
 // Win-style process handling
@@ -9,7 +11,8 @@
 #include <fcntl.h>
 #include <windows.h>
 #include <io.h>
-#else
+
+#else // USING_WIN32
 
 #if defined(HAVE_SYS_WAIT_H) && defined(HAVE_SYS_TYPES_H) && defined(HAVE_UNISTD_H) && defined(HAVE_SIGNAL_H)
 
@@ -18,12 +21,17 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <signal.h>
-
 #define USING_UNIX_PROCESSES
-#else
+
+#else // unix headers
+
 #warning "no process handling style selected"
-#endif
-#endif
+
+#endif // unix headers
+
+#endif // USING_WIN32
+
+#endif // NO_PROCESSHANDLING
 
 ///////////////////////////////////////////////////////////
 
@@ -70,6 +78,10 @@ void kill_additional_procs(const svector& extra_kill) {
 bool Process::start(const STD_string& cmdline, bool block_till_finished, bool log_std_streams) {
   Log<ProcessComponent> odinlog("Process","start");
 
+#ifdef NO_PROCESSHANDLING
+  ODINLOG(odinlog,errorLog) << "NO_PROCESSHANDLING defined" << STD_endl;
+  return false;
+#endif
 
   svector cmdtoks(tokens(cmdline));
   unsigned int ntoks=cmdtoks.size();
@@ -195,8 +207,8 @@ bool Process::start(const STD_string& cmdline, bool block_till_finished, bool lo
 
     // Use shell so that cmdline args are passed properly, i.e. we do not have to tokenize them ourselves
     char *argv[4];
-    argv[0] = "sh";
-    argv[1] = "-c";
+    argv[0] = (char*)"sh";
+    argv[1] = (char*)"-c";
     argv[2] = (char*)cmdline.c_str();  // arggg!
     argv[3] = 0;
     execv("/bin/sh", argv);
@@ -310,8 +322,12 @@ bool Process::finished(int& proc_return_value, bool block_till_finished) {
     STD_cout << coutstr;
     STD_cerr << cerrstr;
   } else {
-    if(coutstr.length()) ODINLOG(odinlog,infoLog) << coutstr; // dump stdout result of child process
-    if(cerrstr.length()) ODINLOG(odinlog,errorLog) << cerrstr; // dump stderr result of child process
+    if(coutstr.length()) {
+      ODINLOG(odinlog,infoLog) << coutstr; // dump stdout result of child process
+    }
+    if(cerrstr.length()) {
+      ODINLOG(odinlog,errorLog) << cerrstr; // dump stderr result of child process
+    }
   }
   return result;
 }
