@@ -2,7 +2,7 @@
                           tjtest.h  -  description
                              -------------------
     begin                : Mon Dec 12 2005
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -46,7 +46,7 @@ class UnitTest : public StaticHandler<UnitTest>, public Labeled {
 
  protected:
 
-  UnitTest(const char* label);
+  UnitTest(const STD_string& testlabel);
   virtual ~UnitTest() {}
 
  private:
