@@ -6,6 +6,8 @@
 #include "tjstring.h"
 #include "tjtest.h"
 #include "tjvector.h" // for testing browse_dir
+#include "tjstd.h" // for unit test
+
 
 
 #include <stdio.h>
@@ -150,24 +152,33 @@ LONGEST_INT filesize(const char *filename) {
   Log<TjTools> odinlog("","filesize");
   LONGEST_INT result=-1;
 
-#ifdef STAT
-  struct STAT st;
-  if(!STAT(filename, &st)) result=st.st_size;
-  else if(errno!=ENOENT) ODINLOG(odinlog,errorLog) << "stat(" << filename << "): " << lasterr() << STD_endl;
+#ifdef ODIN_STAT
+  struct ODIN_STAT st;
+  if(!ODIN_STAT(filename, &st)) result=st.st_size;
+  else if(errno!=ENOENT) {
+    ODINLOG(odinlog,errorLog) << "stat(" << filename << "): " << lasterr() << STD_endl;
+  }
 #else
 
   FILE *file_ptr;
 
-  file_ptr = FOPEN(filename, modestring(readMode));
+  file_ptr = ODIN_FOPEN(filename, modestring(readMode));
   if(file_ptr == NULL) {
-    if(errno!=ENOENT) ODINLOG(odinlog,errorLog) << "fopen(" << filename << "): " << lasterr() << STD_endl;
+    if(errno!=ENOENT) {
+      ODINLOG(odinlog,errorLog) << "fopen(" << filename << "): " << lasterr() << STD_endl;
+    }
     return result;
   }
+  ODINLOG(odinlog,normalDebug) << "file_ptr(" << filename << ")=" << file_ptr << STD_endl;
 
-  if(fgetc(file_ptr) != EOF) {
-    if(fseek(file_ptr, 0, SEEK_END)) {
-       if(errno!=ENOENT) ODINLOG(odinlog,errorLog) << "fseek(" << filename << "): " << lasterr() << STD_endl;
-    } else result=FTELL(file_ptr);
+  if(fgetc(file_ptr) == EOF) {
+    result=0;
+  } else {
+    if(ODIN_FSEEK(file_ptr, 0, SEEK_END)) {
+       if(errno!=ENOENT) {
+         ODINLOG(odinlog,errorLog) << "fseek(" << filename << "): " << lasterr() << STD_endl;
+       }
+    } else result=ODIN_FTELL(file_ptr);
   }
 
   fclose(file_ptr);
@@ -191,7 +202,9 @@ const char* getpwd() {
   result=getcwd(getpwd_buff,ODIN_MAXCHAR);
 #endif
 #endif
-  if(result==NULL) ODINLOG(odinlog,errorLog) << lasterr() << STD_endl;
+  if(result==NULL) {
+    ODINLOG(odinlog,errorLog) << lasterr() << STD_endl;
+  }
   return result;
 }
 
@@ -208,7 +221,9 @@ int chpwd(const char *dirname) {
   result=chdir(dirname);
 #endif
 #endif
-  if(result<0) ODINLOG(odinlog,errorLog) << "(" << dirname << ")" << lasterr() << STD_endl;
+  if(result<0) {
+    ODINLOG(odinlog,errorLog) << "(" << dirname << ")" << lasterr() << STD_endl;
+  }
   return result;
 }
 
@@ -226,7 +241,9 @@ int createdir(const char *dirname) {
   result=mkdir(dirname, S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH); // permission: 0755
 #endif
 #endif
-  if(result<0) ODINLOG(odinlog,errorLog) << "(" << dirname << ") " << lasterr() << STD_endl;
+  if(result<0) {
+    ODINLOG(odinlog,errorLog) << "(" << dirname << ") " << lasterr() << STD_endl;
+  }
   return result;
 }
 
@@ -278,7 +295,9 @@ int copyfile(const char *src, const char* dst) {
 #else
   result=system((STD_string("cp ")+src+" "+dst).c_str());
 #endif
-  if(result<0) ODINLOG(odinlog,errorLog) << "(" << src << "," << dst << ") " << lasterr() << STD_endl;
+  if(result<0) {
+    ODINLOG(odinlog,errorLog) << "(" << src << "," << dst << ") " << lasterr() << STD_endl;
+  }
   return result;
 }
 
@@ -292,14 +311,20 @@ int rmfile(const char *fname) {
 #ifdef USING_WIN32
   if(checkdir(fname)) {
     result=_rmdir(fname);
-    if(result<0) ODINLOG(odinlog,errorLog) << "_rmdir(" << fname << ") " << lasterr() << STD_endl;
+    if(result<0) {
+      ODINLOG(odinlog,errorLog) << "_rmdir(" << fname << ") " << lasterr() << STD_endl;
+    }
   } else {
     result=remove(fname);
-    if(result<0) ODINLOG(odinlog,errorLog) << "remove(" << fname << ") " << lasterr() << STD_endl;
+    if(result<0) {
+      ODINLOG(odinlog,errorLog) << "remove(" << fname << ") " << lasterr() << STD_endl;
+    }
   }
 #else
   result=remove(fname); // Works for both, files and directories
-  if(result<0) ODINLOG(odinlog,errorLog) << "(" << fname << ") " << lasterr() << STD_endl;
+  if(result<0) {
+    ODINLOG(odinlog,errorLog) << "(" << fname << ") " << lasterr() << STD_endl;
+  }
 #endif
   return result;
 }
@@ -330,7 +355,7 @@ int create_empty_file(const STD_string& filename, LONGEST_INT nbytes, fopenMode
   LONGEST_INT i;
   for(i=0; i<BLOCKSIZE; i++) buff[i]=0;
 
-  FILE* fptr=FOPEN(filename.c_str(),modestring(mode));
+  FILE* fptr=ODIN_FOPEN(filename.c_str(),modestring(mode));
   if(fptr==NULL) {
     ODINLOG(odinlog,errorLog) << "fopen: " << lasterr() << STD_endl;
     return -1;
@@ -415,7 +440,7 @@ void* filemap(const STD_string& filename, LONGEST_INT nbytes, LONGEST_INT offset
 
   int flags=O_RDWR;
   if(readonly) flags=O_RDONLY;
-  fd = OPEN( filename.c_str(), flags );
+  fd = ODIN_OPEN( filename.c_str(), flags );
   ODINLOG(odinlog,normalDebug) << "fd = " << fd << STD_endl;
 
   if (fd < 0) {
@@ -432,7 +457,7 @@ void* filemap(const STD_string& filename, LONGEST_INT nbytes, LONGEST_INT offset
 
   int prot=PROT_READ | PROT_WRITE;
   if(readonly) prot=PROT_READ;
-  char* byte_ptr=(char*)MMAP( 0, nbytes+rest_psize, prot, MAP_SHARED, fd, offset_psize );
+  char* byte_ptr=(char*)ODIN_MMAP( 0, nbytes+rest_psize, prot, MAP_SHARED, fd, offset_psize );
   if ( byte_ptr==MAP_FAILED ) {
     ODINLOG(odinlog,errorLog) << "Cannot filemap file >" << filename << "< - " << lasterr() << STD_endl;
     close(fd); fd=-1;
@@ -447,14 +472,14 @@ void* filemap(const STD_string& filename, LONGEST_INT nbytes, LONGEST_INT offset
   const char* modeString=modestring(overwriteMode);
   if(readonly) modeString=modestring(readMode);
 
-  fd=(int)FOPEN(filename.c_str(), modeString);
+  fd=(int)ODIN_FOPEN(filename.c_str(), modeString);
   if(!fd) {
     ODINLOG(odinlog,errorLog) << "fopen: " << lasterr() << STD_endl;
     return result;
   }
 
   if(offset>0) {
-    if(FSEEK((FILE*)fd, offset, SEEK_SET)) {
+    if(ODIN_FSEEK((FILE*)fd, offset, SEEK_SET)) {
       ODINLOG(odinlog,errorLog) << "fseek: " << lasterr() << STD_endl;
       fclose((FILE*)fd);
       return result;
@@ -493,15 +518,19 @@ void fileunmap(int fd, void* start, LONGEST_INT nbytes, LONGEST_INT offset) {
   void* mstart=(char*)start-rest_psize;
   LONGEST_INT mlength=nbytes+rest_psize;
 
-  if ( msync(mstart, mlength, MS_SYNC) ) ODINLOG(odinlog,errorLog) << "msync: "  << lasterr() << STD_endl;
-  if ( munmap(mstart, mlength) )         ODINLOG(odinlog,errorLog) << "munmap: " << lasterr() << STD_endl;
+  if ( msync(mstart, mlength, MS_SYNC) ) {
+    ODINLOG(odinlog,errorLog) << "msync: "  << lasterr() << STD_endl;
+  }
+  if ( munmap(mstart, mlength) ) {
+    ODINLOG(odinlog,errorLog) << "munmap: " << lasterr() << STD_endl;
+  }
   close(fd);
 
 #else // Emulate munmap by writing memory to file, de-allocating memory and closing the file
 
   if(fd>0) { // File is mapped with read/write access
     if(offset>0) {
-      if(FSEEK((FILE*)fd, offset, SEEK_SET)) {
+      if(ODIN_FSEEK((FILE*)fd, offset, SEEK_SET)) {
         ODINLOG(odinlog,errorLog) << "fseek: " << lasterr() << STD_endl;
         fclose((FILE*)fd);
         delete[] (char*)start;
@@ -723,56 +752,73 @@ class TjToolsTest : public UnitTest {
       return false;
     }
 
-    STD_string testcont="content";
-    STD_string srcfile=dir+SEPARATOR_STR+"src";
-    if(write(testcont, srcfile)) {
-      ODINLOG(odinlog,errorLog) << "write failed" << STD_endl;
-      return false;
-    }
+    STD_list<STD_string> contentlist;
+    contentlist.push_back("content");
+    contentlist.push_back("");
 
-    int ntestfiles=5;
-    for(int i=0; i<ntestfiles; i++) {
-      STD_string dstfile=dir+SEPARATOR_STR+itos(i);
-      if(copyfile(srcfile.c_str(), dstfile.c_str())) {
-        ODINLOG(odinlog,errorLog) << "copyfile failed" << STD_endl;
+    for(STD_list<STD_string>::iterator it=contentlist.begin(); it!=contentlist.end(); ++it) {
+
+      STD_string testcont=*it;
+      STD_string srcfile=dir+SEPARATOR_STR+"src";
+      if(write(testcont, srcfile)) {
+        ODINLOG(odinlog,errorLog) << "write(testcont=>" << testcont << "<) failed" << STD_endl;
         return false;
       }
-    }
 
-    if(rmfile(srcfile.c_str())) {
-      ODINLOG(odinlog,errorLog) << "rmfile(srcfile) failed" << STD_endl;
-      return false;
-    }
+      int ntestfiles=5;
+      for(int i=0; i<ntestfiles; i++) {
+        STD_string dstfile=dir+SEPARATOR_STR+itos(i);
+        if(copyfile(srcfile.c_str(), dstfile.c_str())) {
+          ODINLOG(odinlog,errorLog) << "copyfile(testcont=>" << testcont << "<) failed" << STD_endl;
+          return false;
+        }
+      }
 
-    svector browsefiles=browse_dir(dir,false,true);
-    int nbrowsefiles=browsefiles.size();
-    if(nbrowsefiles!=ntestfiles) {
-      ODINLOG(odinlog,errorLog) << "ntestfiles/nbrowsefiles=" << ntestfiles << "/" << nbrowsefiles << STD_endl;
-      return false;
-    }
-
-
-    for(int i=0; i<nbrowsefiles; i++) {
-      STD_string fname=dir+SEPARATOR_STR+browsefiles[i];
-      STD_string filecont;
-      if(load(filecont, fname)) {
-        ODINLOG(odinlog,errorLog) << "load failed" << STD_endl;
+      if(rmfile(srcfile.c_str())) {
+        ODINLOG(odinlog,errorLog) << "rmfile(srcfile, testcont=>" << testcont << "<) failed" << STD_endl;
         return false;
       }
-      if(filecont!=testcont) {
-        ODINLOG(odinlog,errorLog) << "filecont=" << filecont << STD_endl;
+
+      svector browsefiles=browse_dir(dir,false,true);
+      int nbrowsefiles=browsefiles.size();
+      if(nbrowsefiles!=ntestfiles) {
+        ODINLOG(odinlog,errorLog) << "ntestfiles/nbrowsefiles(testcont=>" << testcont << "<)=" << ntestfiles << "/" << nbrowsefiles << STD_endl;
         return false;
       }
-      if(rmfile(fname.c_str())) {
-        ODINLOG(odinlog,errorLog) << "rmfile(browsefiles) failed" << STD_endl;
-        return false;
+
+
+      for(int i=0; i<nbrowsefiles; i++) {
+        STD_string fname=dir+SEPARATOR_STR+browsefiles[i];
+
+        // testing filesize
+        int fsize=filesize(fname.c_str());
+        int strsize=testcont.length();
+        if(fsize!=strsize) {
+          ODINLOG(odinlog,errorLog) << "filesize(testcont=>" << testcont << "<) mismatch, fsize/strsize=" << fsize << "/" << strsize << STD_endl;
+          return false;
+        }
+
+        STD_string filecont;
+        if(load(filecont, fname)) {
+          ODINLOG(odinlog,errorLog) << "load(testcont=>" << testcont << "<) failed" << STD_endl;
+          return false;
+        }
+        if(filecont!=testcont) {
+          ODINLOG(odinlog,errorLog) << "filecont(testcont=>" << testcont << "<)=" << filecont << STD_endl;
+          return false;
+        }
+        if(rmfile(fname.c_str())) {
+          ODINLOG(odinlog,errorLog) << "rmfile(browsefiles, testcont=>" << testcont << "<) failed" << STD_endl;
+          return false;
+        }
       }
+
     }
 
     // Check whether directory is empty
-    browsefiles=browse_dir(dir,false,true);
-    if(browsefiles.size()) {
-      ODINLOG(odinlog,errorLog) << "dir not empty, browsefiles=" << browsefiles.printbody() << STD_endl;
+    svector browsefiles_check=browse_dir(dir,false,true);
+    if(browsefiles_check.size()) {
+      ODINLOG(odinlog,errorLog) << "dir not empty, browsefiles=" << browsefiles_check.printbody() << STD_endl;
       return false;
     }
 
