@@ -120,8 +120,12 @@ ValList<T>& ValList<T>::add_sublist(const ValList<T>& svl) {
 
   if(!data->sublists && !data->val) {
     ODINLOG(odinlog,normalDebug) << "assigning"  << STD_endl;
-    if(svl.data->val) ODINLOG(odinlog,normalDebug) << "svl has val"  << STD_endl;
-    if(svl.data->sublists) ODINLOG(odinlog,normalDebug) << "svl has sublists"  << STD_endl;
+    if(svl.data->val) {
+      ODINLOG(odinlog,normalDebug) << "svl has val"  << STD_endl;
+    }
+    if(svl.data->sublists) {
+      ODINLOG(odinlog,normalDebug) << "svl has sublists"  << STD_endl;
+    }
     STD_string label_cache(get_label());
     (*this)=svl;
     set_label(label_cache);
