@@ -178,6 +178,8 @@ STD_string tokenstring(const svector& tokens,unsigned int linewidth) {
 
 ////////////////////////////////////////
 
+#ifndef NO_FILEHANDLING
+
 svector browse_dir(const STD_string& dirname,bool only_dirs, bool discard_dotfiles) {
   Log<VectorComp> odinlog("","browse_dir");
 
@@ -261,14 +263,18 @@ svector browse_dir(const STD_string& dirname,bool only_dirs, bool discard_dotfil
   return list2vector(result);
 }
 
+#endif // NO_FILEHANDLING
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 
 STD_string svector::printbody() const {
+  return tokenstring(*this,_DEFAULT_LINEWIDTH_);
+/*
   STD_string result;
   for(unsigned int i=0; i<size(); i++) result+=(*this)[i]+" ";
   return result;
+*/
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -665,7 +671,7 @@ int tjvector<T>::load(const STD_string& fname) {
   LONGEST_INT fsize=filesize(fname.c_str());
   LONGEST_INT nelements=fsize/sizeof(T);
 
-  FILE* file_ptr=FOPEN(fname.c_str(),modestring(readMode));
+  FILE* file_ptr=ODIN_FOPEN(fname.c_str(),modestring(readMode));
   if(file_ptr==NULL) {
     ODINLOG(odinlog,errorLog) << "unable to open file >" << fname << "<, " << lasterr() << STD_endl;
     return(-1);
@@ -700,7 +706,7 @@ int tjvector<T>::write(const STD_string& fname, fopenMode mode, LONGEST_INT nele
     nelements=length();
   }
 
-  FILE* file_ptr=FOPEN(fname.c_str(),modestring(mode));
+  FILE* file_ptr=ODIN_FOPEN(fname.c_str(),modestring(mode));
 
   if(file_ptr==NULL) {
     ODINLOG(odinlog,errorLog) << "unable to create/open file >" << fname << "<, " << lasterr() << STD_endl;
