@@ -2,7 +2,7 @@
                           tjvector.h  -  description
                              -------------------
     begin                : Thu Feb 22 2001
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -472,7 +472,7 @@ struct svector : public STD_vector<STD_string> {
   svector(const STD_vector<STD_string>& sv) {svector::operator = (sv);}
   svector& operator = (const STD_vector<STD_string>& sv) {STD_vector<STD_string>::operator = (sv); return *this;}
 
-  // interface functions for JDXarray
+  // interface functions for LDRarray
   unsigned char* c_array() const {return 0;}
   svector& set_c_array(const unsigned char*, unsigned int) {return *this;}
   static unsigned char* allocate_memory(unsigned int) {return 0;}
@@ -567,6 +567,7 @@ STD_vector<T> list2vector(const STD_list<T>& src) {
   STD_string tokenstring(const svector& tokens,unsigned int linewidth=_DEFAULT_LINEWIDTH_);
 
 
+#ifndef NO_FILEHANDLING
 /**
   *
   * Returns all entries in the given directory, if 'only_dirs' is 'true'
@@ -575,6 +576,7 @@ STD_vector<T> list2vector(const STD_list<T>& src) {
   * The resulting vector is sorted alphanumerically according to the file names.
   */
   svector browse_dir(const STD_string& dirname,bool only_dirs=false, bool discard_dotfiles=false);
+#endif
 
 
 
